# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v19.common.types import ad_asset
from google.ads.googleads.v19.enums.types import call_conversion_reporting_state
from google.ads.googleads.v19.enums.types import display_ad_format_setting
from google.ads.googleads.v19.enums.types import (
    display_upload_product_type as gage_display_upload_product_type,
)
from google.ads.googleads.v19.enums.types import legacy_app_install_ad_app_store
from google.ads.googleads.v19.enums.types import mime_type as gage_mime_type
from google.ads.googleads.v19.enums.types import video_thumbnail


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.common",
    marshal="google.ads.googleads.v19",
    manifest={
        "TextAdInfo",
        "ExpandedTextAdInfo",
        "ExpandedDynamicSearchAdInfo",
        "HotelAdInfo",
        "TravelAdInfo",
        "ShoppingSmartAdInfo",
        "ShoppingProductAdInfo",
        "ShoppingComparisonListingAdInfo",
        "ImageAdInfo",
        "VideoBumperInStreamAdInfo",
        "VideoNonSkippableInStreamAdInfo",
        "VideoTrueViewInStreamAdInfo",
        "VideoOutstreamAdInfo",
        "InFeedVideoAdInfo",
        "YouTubeAudioAdInfo",
        "VideoAdInfo",
        "VideoResponsiveAdInfo",
        "ResponsiveSearchAdInfo",
        "LegacyResponsiveDisplayAdInfo",
        "AppAdInfo",
        "AppEngagementAdInfo",
        "AppPreRegistrationAdInfo",
        "LegacyAppInstallAdInfo",
        "ResponsiveDisplayAdInfo",
        "LocalAdInfo",
        "DisplayUploadAdInfo",
        "ResponsiveDisplayAdControlSpec",
        "SmartCampaignAdInfo",
        "CallAdInfo",
        "DemandGenMultiAssetAdInfo",
        "DemandGenCarouselAdInfo",
        "DemandGenVideoResponsiveAdInfo",
        "DemandGenProductAdInfo",
    },
)


class TextAdInfo(proto.Message):
    r"""A text ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        headline (str):
            The headline of the ad.

            This field is a member of `oneof`_ ``_headline``.
        description1 (str):
            The first line of the ad's description.

            This field is a member of `oneof`_ ``_description1``.
        description2 (str):
            The second line of the ad's description.

            This field is a member of `oneof`_ ``_description2``.
    """

    headline: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    description1: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )


class ExpandedTextAdInfo(proto.Message):
    r"""An expanded text ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        headline_part1 (str):
            The first part of the ad's headline.

            This field is a member of `oneof`_ ``_headline_part1``.
        headline_part2 (str):
            The second part of the ad's headline.

            This field is a member of `oneof`_ ``_headline_part2``.
        headline_part3 (str):
            The third part of the ad's headline.

            This field is a member of `oneof`_ ``_headline_part3``.
        description (str):
            The description of the ad.

            This field is a member of `oneof`_ ``_description``.
        description2 (str):
            The second description of the ad.

            This field is a member of `oneof`_ ``_description2``.
        path1 (str):
            The text that can appear alongside the ad's
            displayed URL.

            This field is a member of `oneof`_ ``_path1``.
        path2 (str):
            Additional text that can appear alongside the
            ad's displayed URL.

            This field is a member of `oneof`_ ``_path2``.
    """

    headline_part1: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    headline_part2: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    headline_part3: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=12,
        optional=True,
    )
    path1: str = proto.Field(
        proto.STRING,
        number=13,
        optional=True,
    )
    path2: str = proto.Field(
        proto.STRING,
        number=14,
        optional=True,
    )


class ExpandedDynamicSearchAdInfo(proto.Message):
    r"""An expanded dynamic search ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        description (str):
            The description of the ad.

            This field is a member of `oneof`_ ``_description``.
        description2 (str):
            The second description of the ad.

            This field is a member of `oneof`_ ``_description2``.
    """

    description: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )


class HotelAdInfo(proto.Message):
    r"""A hotel ad."""


class TravelAdInfo(proto.Message):
    r"""A travel ad."""


class ShoppingSmartAdInfo(proto.Message):
    r"""A Smart Shopping ad."""


class ShoppingProductAdInfo(proto.Message):
    r"""A standard Shopping ad."""


class ShoppingComparisonListingAdInfo(proto.Message):
    r"""A Shopping Comparison Listing ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        headline (str):
            Headline of the ad. This field is required.
            Allowed length is between 25 and 45 characters.

            This field is a member of `oneof`_ ``_headline``.
    """

    headline: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class ImageAdInfo(proto.Message):
    r"""An image ad.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        pixel_width (int):
            Width in pixels of the full size image.

            This field is a member of `oneof`_ ``_pixel_width``.
        pixel_height (int):
            Height in pixels of the full size image.

            This field is a member of `oneof`_ ``_pixel_height``.
        image_url (str):
            URL of the full size image.

            This field is a member of `oneof`_ ``_image_url``.
        preview_pixel_width (int):
            Width in pixels of the preview size image.

            This field is a member of `oneof`_ ``_preview_pixel_width``.
        preview_pixel_height (int):
            Height in pixels of the preview size image.

            This field is a member of `oneof`_ ``_preview_pixel_height``.
        preview_image_url (str):
            URL of the preview size image.

            This field is a member of `oneof`_ ``_preview_image_url``.
        mime_type (google.ads.googleads.v19.enums.types.MimeTypeEnum.MimeType):
            The mime type of the image.
        name (str):
            The name of the image. If the image was
            created from a MediaFile, this is the
            MediaFile's name. If the image was created from
            bytes, this is empty.

            This field is a member of `oneof`_ ``_name``.
        image_asset (google.ads.googleads.v19.common.types.AdImageAsset):
            The image assets used for the ad.

            This field is a member of `oneof`_ ``image``.
        data (bytes):
            Raw image data as bytes.

            This field is a member of `oneof`_ ``image``.
        ad_id_to_copy_image_from (int):
            An ad ID to copy the image from.

            This field is a member of `oneof`_ ``image``.
    """

    pixel_width: int = proto.Field(
        proto.INT64,
        number=15,
        optional=True,
    )
    pixel_height: int = proto.Field(
        proto.INT64,
        number=16,
        optional=True,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    preview_pixel_width: int = proto.Field(
        proto.INT64,
        number=18,
        optional=True,
    )
    preview_pixel_height: int = proto.Field(
        proto.INT64,
        number=19,
        optional=True,
    )
    preview_image_url: str = proto.Field(
        proto.STRING,
        number=20,
        optional=True,
    )
    mime_type: gage_mime_type.MimeTypeEnum.MimeType = proto.Field(
        proto.ENUM,
        number=10,
        enum=gage_mime_type.MimeTypeEnum.MimeType,
    )
    name: str = proto.Field(
        proto.STRING,
        number=21,
        optional=True,
    )
    image_asset: ad_asset.AdImageAsset = proto.Field(
        proto.MESSAGE,
        number=22,
        oneof="image",
        message=ad_asset.AdImageAsset,
    )
    data: bytes = proto.Field(
        proto.BYTES,
        number=13,
        oneof="image",
    )
    ad_id_to_copy_image_from: int = proto.Field(
        proto.INT64,
        number=14,
        oneof="image",
    )


class VideoBumperInStreamAdInfo(proto.Message):
    r"""Representation of video bumper in-stream ad format (very
    short in-stream non-skippable video ad).

    Attributes:
        companion_banner (google.ads.googleads.v19.common.types.AdImageAsset):
            The image assets of the companion banner used
            with the ad.
        action_button_label (str):
            Label on the "Call To Action" button taking
            the user to the video ad's final URL.
        action_headline (str):
            Additional text displayed with the CTA
            (call-to-action) button to give context and
            encourage clicking on the button.
    """

    companion_banner: ad_asset.AdImageAsset = proto.Field(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdImageAsset,
    )
    action_button_label: str = proto.Field(
        proto.STRING,
        number=4,
    )
    action_headline: str = proto.Field(
        proto.STRING,
        number=5,
    )


class VideoNonSkippableInStreamAdInfo(proto.Message):
    r"""Representation of video non-skippable in-stream ad format (15
    second in-stream non-skippable video ad).

    Attributes:
        companion_banner (google.ads.googleads.v19.common.types.AdImageAsset):
            The image assets of the companion banner used
            with the ad.
        action_button_label (str):
            Label on the "Call To Action" button taking
            the user to the video ad's final URL.
        action_headline (str):
            Additional text displayed with the "Call To
            Action" button to give context and encourage
            clicking on the button.
    """

    companion_banner: ad_asset.AdImageAsset = proto.Field(
        proto.MESSAGE,
        number=5,
        message=ad_asset.AdImageAsset,
    )
    action_button_label: str = proto.Field(
        proto.STRING,
        number=3,
    )
    action_headline: str = proto.Field(
        proto.STRING,
        number=4,
    )


class VideoTrueViewInStreamAdInfo(proto.Message):
    r"""Representation of video TrueView in-stream ad format (ad
    shown during video playback, often at beginning, which displays
    a skip button a few seconds into the video).

    Attributes:
        action_button_label (str):
            Label on the CTA (call-to-action) button
            taking the user to the video ad's final URL.
            Required for TrueView for action campaigns,
            optional otherwise.
        action_headline (str):
            Additional text displayed with the CTA
            (call-to-action) button to give context and
            encourage clicking on the button.
        companion_banner (google.ads.googleads.v19.common.types.AdImageAsset):
            The image assets of the companion banner used
            with the ad.
    """

    action_button_label: str = proto.Field(
        proto.STRING,
        number=4,
    )
    action_headline: str = proto.Field(
        proto.STRING,
        number=5,
    )
    companion_banner: ad_asset.AdImageAsset = proto.Field(
        proto.MESSAGE,
        number=7,
        message=ad_asset.AdImageAsset,
    )


class VideoOutstreamAdInfo(proto.Message):
    r"""Representation of video out-stream ad format (ad shown
    alongside a feed with automatic playback, without sound).

    Attributes:
        headline (str):
            The headline of the ad.
        description (str):
            The description line.
    """

    headline: str = proto.Field(
        proto.STRING,
        number=3,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
    )


class InFeedVideoAdInfo(proto.Message):
    r"""Representation of In-feed video ad format.

    Attributes:
        headline (str):
            The headline of the ad.
        description1 (str):
            First text line for the ad.
        description2 (str):
            Second text line for the ad.
        thumbnail (google.ads.googleads.v19.enums.types.VideoThumbnailEnum.VideoThumbnail):
            Video thumbnail image to use.
    """

    headline: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description1: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=3,
    )
    thumbnail: video_thumbnail.VideoThumbnailEnum.VideoThumbnail = proto.Field(
        proto.ENUM,
        number=4,
        enum=video_thumbnail.VideoThumbnailEnum.VideoThumbnail,
    )


class YouTubeAudioAdInfo(proto.Message):
    r"""Representation of YouTube Audio ad format."""


class VideoAdInfo(proto.Message):
    r"""A video ad.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        video (google.ads.googleads.v19.common.types.AdVideoAsset):
            The YouTube video assets used for the ad.
        in_stream (google.ads.googleads.v19.common.types.VideoTrueViewInStreamAdInfo):
            Video TrueView in-stream ad format.

            This field is a member of `oneof`_ ``format``.
        bumper (google.ads.googleads.v19.common.types.VideoBumperInStreamAdInfo):
            Video bumper in-stream ad format.

            This field is a member of `oneof`_ ``format``.
        out_stream (google.ads.googleads.v19.common.types.VideoOutstreamAdInfo):
            Video out-stream ad format.

            This field is a member of `oneof`_ ``format``.
        non_skippable (google.ads.googleads.v19.common.types.VideoNonSkippableInStreamAdInfo):
            Video non-skippable in-stream ad format.

            This field is a member of `oneof`_ ``format``.
        in_feed (google.ads.googleads.v19.common.types.InFeedVideoAdInfo):
            In-feed video ad format.

            This field is a member of `oneof`_ ``format``.
        audio (google.ads.googleads.v19.common.types.YouTubeAudioAdInfo):
            YouTube Audio ad format.

            This field is a member of `oneof`_ ``format``.
    """

    video: ad_asset.AdVideoAsset = proto.Field(
        proto.MESSAGE,
        number=8,
        message=ad_asset.AdVideoAsset,
    )
    in_stream: "VideoTrueViewInStreamAdInfo" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="format",
        message="VideoTrueViewInStreamAdInfo",
    )
    bumper: "VideoBumperInStreamAdInfo" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="format",
        message="VideoBumperInStreamAdInfo",
    )
    out_stream: "VideoOutstreamAdInfo" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="format",
        message="VideoOutstreamAdInfo",
    )
    non_skippable: "VideoNonSkippableInStreamAdInfo" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="format",
        message="VideoNonSkippableInStreamAdInfo",
    )
    in_feed: "InFeedVideoAdInfo" = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="format",
        message="InFeedVideoAdInfo",
    )
    audio: "YouTubeAudioAdInfo" = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="format",
        message="YouTubeAudioAdInfo",
    )


class VideoResponsiveAdInfo(proto.Message):
    r"""A video responsive ad.

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the short
            headline. Currently, only a single value for the
            short headline is supported.
        long_headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the long
            headline. Currently, only a single value for the
            long headline is supported.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the description.
            Currently, only a single value for the
            description is supported.
        call_to_actions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the button, for
            example, the "Call To Action" button. Currently,
            only a single value for the button is supported.
        videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            List of YouTube video assets used for the ad.
            Currently, only a single value for the YouTube
            video asset is supported.
        companion_banners (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            List of image assets used for the companion
            banner. Currently, only a single value for the
            companion banner asset is supported.
        breadcrumb1 (str):
            First part of text that appears in the ad
            with the displayed URL.
        breadcrumb2 (str):
            Second part of text that appears in the ad
            with the displayed URL.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    long_headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdTextAsset,
    )
    call_to_actions: MutableSequence[ad_asset.AdTextAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=ad_asset.AdTextAsset,
        )
    )
    videos: MutableSequence[ad_asset.AdVideoAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=ad_asset.AdVideoAsset,
    )
    companion_banners: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=6,
            message=ad_asset.AdImageAsset,
        )
    )
    breadcrumb1: str = proto.Field(
        proto.STRING,
        number=7,
    )
    breadcrumb2: str = proto.Field(
        proto.STRING,
        number=8,
    )


class ResponsiveSearchAdInfo(proto.Message):
    r"""A responsive search ad.

    Responsive search ads let you create an ad that adapts to show
    more text, and more relevant messages, to your customers. Enter
    multiple headlines and descriptions when creating a responsive
    search ad, and over time, Google Ads will automatically test
    different combinations and learn which combinations perform
    best. By adapting your ad's content to more closely match
    potential customers' search terms, responsive search ads may
    improve your campaign's performance.

    More information at
    https://support.google.com/google-ads/answer/7684791


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for headlines. When the
            ad serves the headlines will be selected from
            this list.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for descriptions. When
            the ad serves the descriptions will be selected
            from this list.
        path1 (str):
            First part of text that can be appended to
            the URL in the ad.

            This field is a member of `oneof`_ ``_path1``.
        path2 (str):
            Second part of text that can be appended to the URL in the
            ad. This field can only be set when ``path1`` is also set.

            This field is a member of `oneof`_ ``_path2``.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    path1: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    path2: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )


class LegacyResponsiveDisplayAdInfo(proto.Message):
    r"""A legacy responsive display ad. Ads of this type are labeled
    'Responsive ads' in the Google Ads UI.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        short_headline (str):
            The short version of the ad's headline.

            This field is a member of `oneof`_ ``_short_headline``.
        long_headline (str):
            The long version of the ad's headline.

            This field is a member of `oneof`_ ``_long_headline``.
        description (str):
            The description of the ad.

            This field is a member of `oneof`_ ``_description``.
        business_name (str):
            The business name in the ad.

            This field is a member of `oneof`_ ``_business_name``.
        allow_flexible_color (bool):
            Advertiser's consent to allow flexible color. When true, the
            ad may be served with different color if necessary. When
            false, the ad will be served with the specified colors or a
            neutral color. The default value is ``true``. Must be true
            if ``main_color`` and ``accent_color`` are not set.

            This field is a member of `oneof`_ ``_allow_flexible_color``.
        accent_color (str):
            The accent color of the ad in hexadecimal, for example,
            #ffffff for white. If one of ``main_color`` and
            ``accent_color`` is set, the other is required as well.

            This field is a member of `oneof`_ ``_accent_color``.
        main_color (str):
            The main color of the ad in hexadecimal, for example,
            #ffffff for white. If one of ``main_color`` and
            ``accent_color`` is set, the other is required as well.

            This field is a member of `oneof`_ ``_main_color``.
        call_to_action_text (str):
            The call-to-action text for the ad.

            This field is a member of `oneof`_ ``_call_to_action_text``.
        logo_image (str):
            The MediaFile resource name of the logo image
            used in the ad.

            This field is a member of `oneof`_ ``_logo_image``.
        square_logo_image (str):
            The MediaFile resource name of the square
            logo image used in the ad.

            This field is a member of `oneof`_ ``_square_logo_image``.
        marketing_image (str):
            The MediaFile resource name of the marketing
            image used in the ad.

            This field is a member of `oneof`_ ``_marketing_image``.
        square_marketing_image (str):
            The MediaFile resource name of the square
            marketing image used in the ad.

            This field is a member of `oneof`_ ``_square_marketing_image``.
        format_setting (google.ads.googleads.v19.enums.types.DisplayAdFormatSettingEnum.DisplayAdFormatSetting):
            Specifies which format the ad will be served in. Default is
            ALL_FORMATS.
        price_prefix (str):
            Prefix before price. For example, 'as low
            as'.

            This field is a member of `oneof`_ ``_price_prefix``.
        promo_text (str):
            Promotion text used for dynamic formats of
            responsive ads. For example 'Free two-day
            shipping'.

            This field is a member of `oneof`_ ``_promo_text``.
    """

    short_headline: str = proto.Field(
        proto.STRING,
        number=16,
        optional=True,
    )
    long_headline: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=18,
        optional=True,
    )
    business_name: str = proto.Field(
        proto.STRING,
        number=19,
        optional=True,
    )
    allow_flexible_color: bool = proto.Field(
        proto.BOOL,
        number=20,
        optional=True,
    )
    accent_color: str = proto.Field(
        proto.STRING,
        number=21,
        optional=True,
    )
    main_color: str = proto.Field(
        proto.STRING,
        number=22,
        optional=True,
    )
    call_to_action_text: str = proto.Field(
        proto.STRING,
        number=23,
        optional=True,
    )
    logo_image: str = proto.Field(
        proto.STRING,
        number=24,
        optional=True,
    )
    square_logo_image: str = proto.Field(
        proto.STRING,
        number=25,
        optional=True,
    )
    marketing_image: str = proto.Field(
        proto.STRING,
        number=26,
        optional=True,
    )
    square_marketing_image: str = proto.Field(
        proto.STRING,
        number=27,
        optional=True,
    )
    format_setting: (
        display_ad_format_setting.DisplayAdFormatSettingEnum.DisplayAdFormatSetting
    ) = proto.Field(
        proto.ENUM,
        number=13,
        enum=display_ad_format_setting.DisplayAdFormatSettingEnum.DisplayAdFormatSetting,
    )
    price_prefix: str = proto.Field(
        proto.STRING,
        number=28,
        optional=True,
    )
    promo_text: str = proto.Field(
        proto.STRING,
        number=29,
        optional=True,
    )


class AppAdInfo(proto.Message):
    r"""An app ad.

    Attributes:
        mandatory_ad_text (google.ads.googleads.v19.common.types.AdTextAsset):
            Mandatory ad text.
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for headlines. When the
            ad serves the headlines will be selected from
            this list.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for descriptions. When
            the ad serves the descriptions will be selected
            from this list.
        images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            List of image assets that may be displayed
            with the ad.
        youtube_videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            List of YouTube video assets that may be
            displayed with the ad.
        html5_media_bundles (MutableSequence[google.ads.googleads.v19.common.types.AdMediaBundleAsset]):
            List of media bundle assets that may be used
            with the ad.
        app_deep_link (google.ads.googleads.v19.common.types.AdAppDeepLinkAsset):
            An app deep link asset that may be used with
            the ad.
    """

    mandatory_ad_text: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdTextAsset,
    )
    images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=ad_asset.AdImageAsset,
    )
    youtube_videos: MutableSequence[ad_asset.AdVideoAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=5,
            message=ad_asset.AdVideoAsset,
        )
    )
    html5_media_bundles: MutableSequence[ad_asset.AdMediaBundleAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=6,
            message=ad_asset.AdMediaBundleAsset,
        )
    )
    app_deep_link: ad_asset.AdAppDeepLinkAsset = proto.Field(
        proto.MESSAGE,
        number=7,
        message=ad_asset.AdAppDeepLinkAsset,
    )


class AppEngagementAdInfo(proto.Message):
    r"""App engagement ads allow you to write text encouraging a
    specific action in the app, like checking in, making a purchase,
    or booking a flight. They allow you to send users to a specific
    part of your app where they can find what they're looking for
    easier and faster.

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for headlines. When the
            ad serves the headlines will be selected from
            this list.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for descriptions. When
            the ad serves the descriptions will be selected
            from this list.
        images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            List of image assets that may be displayed
            with the ad.
        videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            List of video assets that may be displayed
            with the ad.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdImageAsset,
    )
    videos: MutableSequence[ad_asset.AdVideoAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=ad_asset.AdVideoAsset,
    )


class AppPreRegistrationAdInfo(proto.Message):
    r"""App pre-registration ads link to your app or game listing on
    Google Play, and can run on Google Play, on YouTube (in-stream
    only), and within other apps and mobile websites on the Display
    Network. It will help capture people's interest in your app or
    game and generate an early install base for your app or game
    before a launch.

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for headlines. When the
            ad serves the headlines will be selected from
            this list.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for descriptions. When
            the ad serves the descriptions will be selected
            from this list.
        images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            List of image asset IDs whose images may be
            displayed with the ad.
        youtube_videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            List of YouTube video asset IDs whose videos
            may be displayed with the ad.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdImageAsset,
    )
    youtube_videos: MutableSequence[ad_asset.AdVideoAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=ad_asset.AdVideoAsset,
        )
    )


class LegacyAppInstallAdInfo(proto.Message):
    r"""A legacy app install ad that only can be used by a few select
    customers.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        app_id (str):
            The ID of the mobile app.

            This field is a member of `oneof`_ ``_app_id``.
        app_store (google.ads.googleads.v19.enums.types.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore):
            The app store the mobile app is available in.
        headline (str):
            The headline of the ad.

            This field is a member of `oneof`_ ``_headline``.
        description1 (str):
            The first description line of the ad.

            This field is a member of `oneof`_ ``_description1``.
        description2 (str):
            The second description line of the ad.

            This field is a member of `oneof`_ ``_description2``.
    """

    app_id: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    app_store: (
        legacy_app_install_ad_app_store.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=legacy_app_install_ad_app_store.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore,
    )
    headline: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    description1: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )


class ResponsiveDisplayAdInfo(proto.Message):
    r"""A responsive display ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Marketing images to be used in the ad. Valid image types are
            GIF, JPEG, and PNG. The minimum size is 600x314 and the
            aspect ratio must be 1.91:1 (+-1%). At least one
            ``marketing_image`` is required. Combined with
            ``square_marketing_images``, the maximum is 15.
        square_marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Square marketing images to be used in the ad. Valid image
            types are GIF, JPEG, and PNG. The minimum size is 300x300
            and the aspect ratio must be 1:1 (+-1%). At least one square
            ``marketing_image`` is required. Combined with
            ``marketing_images``, the maximum is 15.
        logo_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Logo images to be used in the ad. Valid image types are GIF,
            JPEG, and PNG. The minimum size is 512x128 and the aspect
            ratio must be 4:1 (+-1%). Combined with
            ``square_logo_images``, the maximum is 5.
        square_logo_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Square logo images to be used in the ad. Valid image types
            are GIF, JPEG, and PNG. The minimum size is 128x128 and the
            aspect ratio must be 1:1 (+-1%). Combined with
            ``logo_images``, the maximum is 5.
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            Short format headlines for the ad. The
            maximum length is 30 characters. At least 1 and
            max 5 headlines can be specified.
        long_headline (google.ads.googleads.v19.common.types.AdTextAsset):
            A required long format headline. The maximum
            length is 90 characters.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            Descriptive texts for the ad. The maximum
            length is 90 characters. At least 1 and max 5
            headlines can be specified.
        youtube_videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            Optional YouTube videos for the ad. A maximum
            of 5 videos can be specified.
        business_name (str):
            The advertiser/brand name. Maximum display
            width is 25.

            This field is a member of `oneof`_ ``_business_name``.
        main_color (str):
            The main color of the ad in hexadecimal, for example,
            #ffffff for white. If one of ``main_color`` and
            ``accent_color`` is set, the other is required as well.

            This field is a member of `oneof`_ ``_main_color``.
        accent_color (str):
            The accent color of the ad in hexadecimal, for example,
            #ffffff for white. If one of ``main_color`` and
            ``accent_color`` is set, the other is required as well.

            This field is a member of `oneof`_ ``_accent_color``.
        allow_flexible_color (bool):
            Advertiser's consent to allow flexible color. When true, the
            ad may be served with different color if necessary. When
            false, the ad will be served with the specified colors or a
            neutral color. The default value is ``true``. Must be true
            if ``main_color`` and ``accent_color`` are not set.

            This field is a member of `oneof`_ ``_allow_flexible_color``.
        call_to_action_text (str):
            The call-to-action text for the ad. Maximum
            display width is 30.

            This field is a member of `oneof`_ ``_call_to_action_text``.
        price_prefix (str):
            Prefix before price. For example, 'as low
            as'.

            This field is a member of `oneof`_ ``_price_prefix``.
        promo_text (str):
            Promotion text used for dynamic formats of
            responsive ads. For example 'Free two-day
            shipping'.

            This field is a member of `oneof`_ ``_promo_text``.
        format_setting (google.ads.googleads.v19.enums.types.DisplayAdFormatSettingEnum.DisplayAdFormatSetting):
            Specifies which format the ad will be served in. Default is
            ALL_FORMATS.
        control_spec (google.ads.googleads.v19.common.types.ResponsiveDisplayAdControlSpec):
            Specification for various creative controls.
    """

    marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=ad_asset.AdImageAsset,
        )
    )
    square_marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message=ad_asset.AdImageAsset,
        )
    )
    logo_images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdImageAsset,
    )
    square_logo_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=ad_asset.AdImageAsset,
        )
    )
    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=ad_asset.AdTextAsset,
    )
    long_headline: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=6,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=ad_asset.AdTextAsset,
    )
    youtube_videos: MutableSequence[ad_asset.AdVideoAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=8,
            message=ad_asset.AdVideoAsset,
        )
    )
    business_name: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    main_color: str = proto.Field(
        proto.STRING,
        number=18,
        optional=True,
    )
    accent_color: str = proto.Field(
        proto.STRING,
        number=19,
        optional=True,
    )
    allow_flexible_color: bool = proto.Field(
        proto.BOOL,
        number=20,
        optional=True,
    )
    call_to_action_text: str = proto.Field(
        proto.STRING,
        number=21,
        optional=True,
    )
    price_prefix: str = proto.Field(
        proto.STRING,
        number=22,
        optional=True,
    )
    promo_text: str = proto.Field(
        proto.STRING,
        number=23,
        optional=True,
    )
    format_setting: (
        display_ad_format_setting.DisplayAdFormatSettingEnum.DisplayAdFormatSetting
    ) = proto.Field(
        proto.ENUM,
        number=16,
        enum=display_ad_format_setting.DisplayAdFormatSettingEnum.DisplayAdFormatSetting,
    )
    control_spec: "ResponsiveDisplayAdControlSpec" = proto.Field(
        proto.MESSAGE,
        number=24,
        message="ResponsiveDisplayAdControlSpec",
    )


class LocalAdInfo(proto.Message):
    r"""A local ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for headlines. When the
            ad serves the headlines will be selected from
            this list. At least 1 and at most 5 headlines
            must be specified.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for descriptions. When
            the ad serves the descriptions will be selected
            from this list. At least 1 and at most 5
            descriptions must be specified.
        call_to_actions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets for call-to-actions. When
            the ad serves the call-to-actions will be
            selected from this list. At least 1 and at most
            5 call-to-actions must be specified.
        marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            List of marketing image assets that may be
            displayed with the ad. The images must be
            314x600 pixels or 320x320 pixels. At least 1 and
            at most 20 image assets must be specified.
        logo_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            List of logo image assets that may be
            displayed with the ad. The images must be
            128x128 pixels and not larger than 120KB. At
            least 1 and at most 5 image assets must be
            specified.
        videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            List of YouTube video assets that may be
            displayed with the ad. At least 1 and at most 20
            video assets must be specified.
        path1 (str):
            First part of optional text that can be
            appended to the URL in the ad.

            This field is a member of `oneof`_ ``_path1``.
        path2 (str):
            Second part of optional text that can be appended to the URL
            in the ad. This field can only be set when ``path1`` is also
            set.

            This field is a member of `oneof`_ ``_path2``.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    call_to_actions: MutableSequence[ad_asset.AdTextAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=3,
            message=ad_asset.AdTextAsset,
        )
    )
    marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=ad_asset.AdImageAsset,
        )
    )
    logo_images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=ad_asset.AdImageAsset,
    )
    videos: MutableSequence[ad_asset.AdVideoAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=ad_asset.AdVideoAsset,
    )
    path1: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    path2: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )


class DisplayUploadAdInfo(proto.Message):
    r"""A generic type of display ad. The exact ad format is controlled by
    the ``display_upload_product_type`` field, which determines what
    kinds of data need to be included with the ad.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        display_upload_product_type (google.ads.googleads.v19.enums.types.DisplayUploadProductTypeEnum.DisplayUploadProductType):
            The product type of this ad. See comments on
            the enum for details.
        media_bundle (google.ads.googleads.v19.common.types.AdMediaBundleAsset):
            A media bundle asset to be used in the ad. For information
            about the media bundle for HTML5_UPLOAD_AD, see
            https://support.google.com/google-ads/answer/1722096 Media
            bundles that are part of dynamic product types use a special
            format that needs to be created through the Google Web
            Designer. See
            https://support.google.com/webdesigner/answer/7543898 for
            more information.

            This field is a member of `oneof`_ ``media_asset``.
    """

    display_upload_product_type: (
        gage_display_upload_product_type.DisplayUploadProductTypeEnum.DisplayUploadProductType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=gage_display_upload_product_type.DisplayUploadProductTypeEnum.DisplayUploadProductType,
    )
    media_bundle: ad_asset.AdMediaBundleAsset = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="media_asset",
        message=ad_asset.AdMediaBundleAsset,
    )


class ResponsiveDisplayAdControlSpec(proto.Message):
    r"""Specification for various creative controls for a responsive
    display ad.

    Attributes:
        enable_asset_enhancements (bool):
            Whether the advertiser has opted into the
            asset enhancements feature.
        enable_autogen_video (bool):
            Whether the advertiser has opted into
            auto-gen video feature.
    """

    enable_asset_enhancements: bool = proto.Field(
        proto.BOOL,
        number=1,
    )
    enable_autogen_video: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class SmartCampaignAdInfo(proto.Message):
    r"""A Smart campaign ad.

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets, each of which
            corresponds to a headline when the ad serves.
            This list consists of a minimum of 3 and up to
            15 text assets.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets, each of which
            corresponds to a description when the ad serves.
            This list consists of a minimum of 2 and up to 4
            text assets.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )


class CallAdInfo(proto.Message):
    r"""A call ad.

    Attributes:
        country_code (str):
            The country code in the ad.
        phone_number (str):
            The phone number in the ad.
        business_name (str):
            The business name in the ad.
        headline1 (str):
            First headline in the ad.
        headline2 (str):
            Second headline in the ad.
        description1 (str):
            The first line of the ad's description.
        description2 (str):
            The second line of the ad's description.
        call_tracked (bool):
            Whether to enable call tracking for the
            creative. Enabling call tracking also enables
            call conversions.
        disable_call_conversion (bool):
            Whether to disable call conversion for the creative. If set
            to ``true``, disables call conversions even when
            ``call_tracked`` is ``true``. If ``call_tracked`` is
            ``false``, this field is ignored.
        phone_number_verification_url (str):
            The URL to be used for phone number
            verification.
        conversion_action (str):
            The conversion action to attribute a call conversion to. If
            not set a default conversion action is used. This field only
            has effect if ``call_tracked`` is set to ``true``. Otherwise
            this field is ignored.
        conversion_reporting_state (google.ads.googleads.v19.enums.types.CallConversionReportingStateEnum.CallConversionReportingState):
            The call conversion behavior of this call ad.
            It can use its own call conversion setting,
            inherit the account level setting, or be
            disabled.
        path1 (str):
            First part of text that can be appended to
            the URL in the ad. Optional.
        path2 (str):
            Second part of text that can be appended to the URL in the
            ad. This field can only be set when ``path1`` is also set.
            Optional.
    """

    country_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    phone_number: str = proto.Field(
        proto.STRING,
        number=2,
    )
    business_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    headline1: str = proto.Field(
        proto.STRING,
        number=11,
    )
    headline2: str = proto.Field(
        proto.STRING,
        number=12,
    )
    description1: str = proto.Field(
        proto.STRING,
        number=4,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=5,
    )
    call_tracked: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    disable_call_conversion: bool = proto.Field(
        proto.BOOL,
        number=7,
    )
    phone_number_verification_url: str = proto.Field(
        proto.STRING,
        number=8,
    )
    conversion_action: str = proto.Field(
        proto.STRING,
        number=9,
    )
    conversion_reporting_state: (
        call_conversion_reporting_state.CallConversionReportingStateEnum.CallConversionReportingState
    ) = proto.Field(
        proto.ENUM,
        number=10,
        enum=call_conversion_reporting_state.CallConversionReportingStateEnum.CallConversionReportingState,
    )
    path1: str = proto.Field(
        proto.STRING,
        number=13,
    )
    path2: str = proto.Field(
        proto.STRING,
        number=14,
    )


class DemandGenMultiAssetAdInfo(proto.Message):
    r"""A Demand Gen multi asset ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Marketing image assets to be used in the ad. Valid image
            types are GIF, JPEG, and PNG. The minimum size is 600x314
            and the aspect ratio must be 1.91:1 (+-1%). Required if
            square_marketing_images is not present. Combined with
            ``square_marketing_images``, ``portrait_marketing_images``,
            and ``tall_portrait_marketing_images`` the maximum is 20.
        square_marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Square marketing image assets to be used in the ad. Valid
            image types are GIF, JPEG, and PNG. The minimum size is
            300x300 and the aspect ratio must be 1:1 (+-1%). Required if
            marketing_images is not present. Combined with
            ``marketing_images``, ``portrait_marketing_images``, and
            ``tall_portrait_marketing_images`` the maximum is 20.
        portrait_marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Portrait marketing image assets to be used in the ad. Valid
            image types are GIF, JPEG, and PNG. The minimum size is
            480x600 and the aspect ratio must be 4:5 (+-1%). Combined
            with ``marketing_images``, ``square_marketing_images``, and
            ``tall_portrait_marketing_images`` the maximum is 20.
        tall_portrait_marketing_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Tall portrait marketing image assets to be used in the ad.
            Valid image types are GIF, JPEG, and PNG. The minimum size
            is 600x1067 and the aspect ratio must be 9:16 (+-1%).
            Combined with ``marketing_images``,
            ``square_marketing_images``, and
            ``portrait_marketing_images``, the maximum is 20.
        logo_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Logo image assets to be used in the ad. Valid
            image types are GIF, JPEG, and PNG. The minimum
            size is 128x128 and the aspect ratio must be 1:1
            (+-1%). At least 1 and max 5 logo images can be
            specified.
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            Headline text asset of the ad. Maximum
            display width is 30. At least 1 and max 5
            headlines can be specified.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            The descriptive text of the ad. Maximum
            display width is 90. At least 1 and max 5
            descriptions can be specified.
        business_name (str):
            The Advertiser/brand name. Maximum display
            width is 25. Required.

            This field is a member of `oneof`_ ``_business_name``.
        call_to_action_text (str):
            Call to action text.

            This field is a member of `oneof`_ ``_call_to_action_text``.
        lead_form_only (bool):
            Boolean option that indicates if this ad must
            be served with lead form.

            This field is a member of `oneof`_ ``_lead_form_only``.
    """

    marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=ad_asset.AdImageAsset,
        )
    )
    square_marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message=ad_asset.AdImageAsset,
        )
    )
    portrait_marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=3,
            message=ad_asset.AdImageAsset,
        )
    )
    tall_portrait_marketing_images: MutableSequence[ad_asset.AdImageAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=10,
            message=ad_asset.AdImageAsset,
        )
    )
    logo_images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=ad_asset.AdImageAsset,
    )
    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=ad_asset.AdTextAsset,
    )
    business_name: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    call_to_action_text: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    lead_form_only: bool = proto.Field(
        proto.BOOL,
        number=9,
        optional=True,
    )


class DemandGenCarouselAdInfo(proto.Message):
    r"""A Demand Gen carousel ad.

    Attributes:
        business_name (str):
            Required. The Advertiser/brand name.
        logo_image (google.ads.googleads.v19.common.types.AdImageAsset):
            Required. Logo image to be used in the ad.
            The minimum size is 128x128 and the aspect ratio
            must be 1:1 (+-1%).
        headline (google.ads.googleads.v19.common.types.AdTextAsset):
            Required. Headline of the ad.
        description (google.ads.googleads.v19.common.types.AdTextAsset):
            Required. The descriptive text of the ad.
        call_to_action_text (str):
            Call to action text.
        carousel_cards (MutableSequence[google.ads.googleads.v19.common.types.AdDemandGenCarouselCardAsset]):
            Required. Carousel cards that will display
            with the ad. Min 2 max 10.
    """

    business_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    logo_image: ad_asset.AdImageAsset = proto.Field(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdImageAsset,
    )
    headline: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdTextAsset,
    )
    description: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=4,
        message=ad_asset.AdTextAsset,
    )
    call_to_action_text: str = proto.Field(
        proto.STRING,
        number=5,
    )
    carousel_cards: MutableSequence[ad_asset.AdDemandGenCarouselCardAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=6,
            message=ad_asset.AdDemandGenCarouselCardAsset,
        )
    )


class DemandGenVideoResponsiveAdInfo(proto.Message):
    r"""A Demand Gen video responsive ad.

    Attributes:
        headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the short
            headline.
        long_headlines (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the long
            headline.
        descriptions (MutableSequence[google.ads.googleads.v19.common.types.AdTextAsset]):
            List of text assets used for the description.
        videos (MutableSequence[google.ads.googleads.v19.common.types.AdVideoAsset]):
            List of YouTube video assets used for the ad.
        logo_images (MutableSequence[google.ads.googleads.v19.common.types.AdImageAsset]):
            Logo image to be used in the ad. Valid image
            types are GIF, JPEG, and PNG. The minimum size
            is 128x128 and the aspect ratio must be 1:1
            (+-1%).
        breadcrumb1 (str):
            First part of text that appears in the ad
            with the displayed URL.
        breadcrumb2 (str):
            Second part of text that appears in the ad
            with the displayed URL.
        business_name (google.ads.googleads.v19.common.types.AdTextAsset):
            Required. The advertiser/brand name.
        call_to_actions (MutableSequence[google.ads.googleads.v19.common.types.AdCallToActionAsset]):
            Assets of type CallToActionAsset used for the
            "Call To Action" button.
    """

    headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=ad_asset.AdTextAsset,
    )
    long_headlines: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ad_asset.AdTextAsset,
    )
    descriptions: MutableSequence[ad_asset.AdTextAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ad_asset.AdTextAsset,
    )
    videos: MutableSequence[ad_asset.AdVideoAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=ad_asset.AdVideoAsset,
    )
    logo_images: MutableSequence[ad_asset.AdImageAsset] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=ad_asset.AdImageAsset,
    )
    breadcrumb1: str = proto.Field(
        proto.STRING,
        number=6,
    )
    breadcrumb2: str = proto.Field(
        proto.STRING,
        number=7,
    )
    business_name: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=8,
        message=ad_asset.AdTextAsset,
    )
    call_to_actions: MutableSequence[ad_asset.AdCallToActionAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=9,
            message=ad_asset.AdCallToActionAsset,
        )
    )


class DemandGenProductAdInfo(proto.Message):
    r"""A Demand Gen product ad.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        headline (google.ads.googleads.v19.common.types.AdTextAsset):
            Required. Text asset used for the short
            headline.

            This field is a member of `oneof`_ ``_headline``.
        description (google.ads.googleads.v19.common.types.AdTextAsset):
            Required. Text asset used for the
            description.

            This field is a member of `oneof`_ ``_description``.
        logo_image (google.ads.googleads.v19.common.types.AdImageAsset):
            Required. Logo image to be used in the ad.
            Valid image types are GIF, JPEG, and PNG. The
            minimum size is 128x128 and the aspect ratio
            must be 1:1 (+-1%).

            This field is a member of `oneof`_ ``_logo_image``.
        breadcrumb1 (str):
            First part of text that appears in the ad
            with the displayed URL.
        breadcrumb2 (str):
            Second part of text that appears in the ad
            with the displayed URL.
        business_name (google.ads.googleads.v19.common.types.AdTextAsset):
            Required. The advertiser/brand name.
        call_to_action (google.ads.googleads.v19.common.types.AdCallToActionAsset):
            Asset of type CallToActionAsset used for the
            "Call To Action" button.

            This field is a member of `oneof`_ ``_call_to_action``.
    """

    headline: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=1,
        optional=True,
        message=ad_asset.AdTextAsset,
    )
    description: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=2,
        optional=True,
        message=ad_asset.AdTextAsset,
    )
    logo_image: ad_asset.AdImageAsset = proto.Field(
        proto.MESSAGE,
        number=3,
        optional=True,
        message=ad_asset.AdImageAsset,
    )
    breadcrumb1: str = proto.Field(
        proto.STRING,
        number=4,
    )
    breadcrumb2: str = proto.Field(
        proto.STRING,
        number=5,
    )
    business_name: ad_asset.AdTextAsset = proto.Field(
        proto.MESSAGE,
        number=6,
        message=ad_asset.AdTextAsset,
    )
    call_to_action: ad_asset.AdCallToActionAsset = proto.Field(
        proto.MESSAGE,
        number=7,
        optional=True,
        message=ad_asset.AdCallToActionAsset,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v20.enums.types import (
    android_privacy_interaction_type as gage_android_privacy_interaction_type,
)
from google.ads.googleads.v20.enums.types import (
    android_privacy_network_type as gage_android_privacy_network_type,
)


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.resources",
    marshal="google.ads.googleads.v20",
    manifest={
        "AndroidPrivacySharedKeyGoogleNetworkType",
    },
)


class AndroidPrivacySharedKeyGoogleNetworkType(proto.Message):
    r"""An Android privacy shared key view for Google network type
    key.

    Attributes:
        resource_name (str):
            Output only. The resource name of the Android privacy shared
            key. Android privacy shared key resource names have the
            form:

            ``customers/{customer_id}/androidPrivacySharedKeyGoogleNetworkTypes/{campaign_id}~{android_privacy_interaction_type}~{android_privacy_network_type}~{android_privacy_interaction_date(yyyy-mm-dd)}``
        campaign_id (int):
            Output only. The campaign ID used in the
            share key encoding.
        android_privacy_interaction_type (google.ads.googleads.v20.enums.types.AndroidPrivacyInteractionTypeEnum.AndroidPrivacyInteractionType):
            Output only. The interaction type enum used
            in the share key encoding.
        android_privacy_interaction_date (str):
            Output only. The interaction date used in the
            shared key encoding in the format of
            "YYYY-MM-DD" in UTC timezone.
        android_privacy_network_type (google.ads.googleads.v20.enums.types.AndroidPrivacyNetworkTypeEnum.AndroidPrivacyNetworkType):
            Output only. The network type enum used in
            the share key encoding.
        shared_network_type_key (str):
            Output only. 128 bit hex string of the
            encoded shared network type key, including a
            '0x' prefix. This key can be used to do a
            bitwise OR operator with the aggregate
            conversion key to create a full aggregation key
            to retrieve the Aggregate API Report in Android
            Privacy Sandbox.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    campaign_id: int = proto.Field(
        proto.INT64,
        number=2,
    )
    android_privacy_interaction_type: (
        gage_android_privacy_interaction_type.AndroidPrivacyInteractionTypeEnum.AndroidPrivacyInteractionType
    ) = proto.Field(
        proto.ENUM,
        number=3,
        enum=gage_android_privacy_interaction_type.AndroidPrivacyInteractionTypeEnum.AndroidPrivacyInteractionType,
    )
    android_privacy_interaction_date: str = proto.Field(
        proto.STRING,
        number=4,
    )
    android_privacy_network_type: (
        gage_android_privacy_network_type.AndroidPrivacyNetworkTypeEnum.AndroidPrivacyNetworkType
    ) = proto.Field(
        proto.ENUM,
        number=5,
        enum=gage_android_privacy_network_type.AndroidPrivacyNetworkTypeEnum.AndroidPrivacyNetworkType,
    )
    shared_network_type_key: str = proto.Field(
        proto.STRING,
        number=6,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.errors",
    marshal="google.ads.googleads.v22",
    manifest={
        "FunctionParsingErrorEnum",
    },
)


class FunctionParsingErrorEnum(proto.Message):
    r"""Container for enum describing possible function parsing
    errors.

    """

    class FunctionParsingError(proto.Enum):
        r"""Enum describing possible function parsing errors.

        Values:
            UNSPECIFIED (0):
                Enum unspecified.
            UNKNOWN (1):
                The received error code is not known in this
                version.
            NO_MORE_INPUT (2):
                Unexpected end of function string.
            EXPECTED_CHARACTER (3):
                Could not find an expected character.
            UNEXPECTED_SEPARATOR (4):
                Unexpected separator character.
            UNMATCHED_LEFT_BRACKET (5):
                Unmatched left bracket or parenthesis.
            UNMATCHED_RIGHT_BRACKET (6):
                Unmatched right bracket or parenthesis.
            TOO_MANY_NESTED_FUNCTIONS (7):
                Functions are nested too deeply.
            MISSING_RIGHT_HAND_OPERAND (8):
                Missing right-hand-side operand.
            INVALID_OPERATOR_NAME (9):
                Invalid operator/function name.
            FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER (10):
                Feed attribute operand's argument is not an
                integer.
            NO_OPERANDS (11):
                Missing function operands.
            TOO_MANY_OPERANDS (12):
                Function had too many operands.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        NO_MORE_INPUT = 2
        EXPECTED_CHARACTER = 3
        UNEXPECTED_SEPARATOR = 4
        UNMATCHED_LEFT_BRACKET = 5
        UNMATCHED_RIGHT_BRACKET = 6
        TOO_MANY_NESTED_FUNCTIONS = 7
        MISSING_RIGHT_HAND_OPERAND = 8
        INVALID_OPERATOR_NAME = 9
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = 10
        NO_OPERANDS = 11
        TOO_MANY_OPERANDS = 12


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.enums",
    marshal="google.ads.googleads.v19",
    manifest={
        "ReachPlanSurfaceEnum",
    },
)


class ReachPlanSurfaceEnum(proto.Message):
    r"""Container for enum describing surfaces available for
    targeting in forecasts. Surfaces refer to the available types of
    ad inventories such as In-Feed, In-Stream, and Shorts.

    """

    class ReachPlanSurface(proto.Enum):
        r"""Surfaces available to target in reach forecasts.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                The value is unknown in this version.
            DISCOVER_FEED (7):
                Discover feed ad surface.
            GMAIL (8):
                Gmail ad surface.
            IN_FEED (2):
                In-Feed ad surface.
            IN_STREAM_BUMPER (3):
                In-Stream bumper ad surface.
            IN_STREAM_NON_SKIPPABLE (4):
                In-Stream non-skippable ad surface.
            IN_STREAM_SKIPPABLE (5):
                In-Stream skippable ad surface.
            SHORTS (6):
                Shorts ad surface.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        DISCOVER_FEED = 7
        GMAIL = 8
        IN_FEED = 2
        IN_STREAM_BUMPER = 3
        IN_STREAM_NON_SKIPPABLE = 4
        IN_STREAM_SKIPPABLE = 5
        SHORTS = 6


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v22.common.types import ad_asset
from google.ads.googleads.v22.common.types import criteria
from google.ads.googleads.v22.common.types import feed_common
from google.ads.googleads.v22.enums.types import (
    business_message_call_to_action_type,
)
from google.ads.googleads.v22.enums.types import business_message_provider
from google.ads.googleads.v22.enums.types import (
    call_conversion_reporting_state as gage_call_conversion_reporting_state,
)
from google.ads.googleads.v22.enums.types import (
    call_to_action_type as gage_call_to_action_type,
)
from google.ads.googleads.v22.enums.types import lead_form_call_to_action_type
from google.ads.googleads.v22.enums.types import lead_form_desired_intent
from google.ads.googleads.v22.enums.types import lead_form_field_user_input_type
from google.ads.googleads.v22.enums.types import (
    lead_form_post_submit_call_to_action_type,
)
from google.ads.googleads.v22.enums.types import (
    location_ownership_type as gage_location_ownership_type,
)
from google.ads.googleads.v22.enums.types import mime_type as gage_mime_type
from google.ads.googleads.v22.enums.types import mobile_app_vendor
from google.ads.googleads.v22.enums.types import price_extension_price_qualifier
from google.ads.googleads.v22.enums.types import price_extension_price_unit
from google.ads.googleads.v22.enums.types import price_extension_type
from google.ads.googleads.v22.enums.types import promotion_barcode_type
from google.ads.googleads.v22.enums.types import (
    promotion_extension_discount_modifier,
)
from google.ads.googleads.v22.enums.types import promotion_extension_occasion


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.common",
    marshal="google.ads.googleads.v22",
    manifest={
        "YoutubeVideoAsset",
        "MediaBundleAsset",
        "ImageAsset",
        "ImageDimension",
        "TextAsset",
        "LeadFormAsset",
        "LeadFormField",
        "LeadFormCustomQuestionField",
        "LeadFormSingleChoiceAnswers",
        "LeadFormDeliveryMethod",
        "WebhookDelivery",
        "BookOnGoogleAsset",
        "PromotionAsset",
        "PromotionBarcodeInfo",
        "PromotionQrCodeInfo",
        "CalloutAsset",
        "StructuredSnippetAsset",
        "SitelinkAsset",
        "PageFeedAsset",
        "DynamicEducationAsset",
        "MobileAppAsset",
        "HotelCalloutAsset",
        "CallAsset",
        "PriceAsset",
        "PriceOffering",
        "CallToActionAsset",
        "DynamicRealEstateAsset",
        "DynamicCustomAsset",
        "DynamicHotelsAndRentalsAsset",
        "DynamicFlightsAsset",
        "DemandGenCarouselCardAsset",
        "DynamicTravelAsset",
        "DynamicLocalAsset",
        "DynamicJobsAsset",
        "LocationAsset",
        "BusinessProfileLocation",
        "HotelPropertyAsset",
        "BusinessMessageAsset",
        "WhatsappBusinessMessageInfo",
        "BusinessMessageCallToActionInfo",
        "AppDeepLinkAsset",
        "YouTubeVideoListAsset",
    },
)


class YoutubeVideoAsset(proto.Message):
    r"""A YouTube asset.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        youtube_video_id (str):
            YouTube video id. This is the 11 character
            string value used in the YouTube video URL.

            This field is a member of `oneof`_ ``_youtube_video_id``.
        youtube_video_title (str):
            YouTube video title.
    """

    youtube_video_id: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    youtube_video_title: str = proto.Field(
        proto.STRING,
        number=3,
    )


class MediaBundleAsset(proto.Message):
    r"""A MediaBundle asset.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        data (bytes):
            Media bundle (ZIP file) asset data. The
            format of the uploaded ZIP file depends on the
            ad field where it will be used. For more
            information on the format, see the documentation
            of the ad field where you plan on using the
            MediaBundleAsset. This field is mutate only.

            This field is a member of `oneof`_ ``_data``.
    """

    data: bytes = proto.Field(
        proto.BYTES,
        number=2,
        optional=True,
    )


class ImageAsset(proto.Message):
    r"""An Image asset.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        data (bytes):
            The raw bytes data of an image. This field is
            mutate only.

            This field is a member of `oneof`_ ``_data``.
        file_size (int):
            File size of the image asset in bytes.

            This field is a member of `oneof`_ ``_file_size``.
        mime_type (google.ads.googleads.v22.enums.types.MimeTypeEnum.MimeType):
            MIME type of the image asset.
        full_size (google.ads.googleads.v22.common.types.ImageDimension):
            Metadata for this image at its original size.
    """

    data: bytes = proto.Field(
        proto.BYTES,
        number=5,
        optional=True,
    )
    file_size: int = proto.Field(
        proto.INT64,
        number=6,
        optional=True,
    )
    mime_type: gage_mime_type.MimeTypeEnum.MimeType = proto.Field(
        proto.ENUM,
        number=3,
        enum=gage_mime_type.MimeTypeEnum.MimeType,
    )
    full_size: "ImageDimension" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="ImageDimension",
    )


class ImageDimension(proto.Message):
    r"""Metadata for an image at a certain size, either original or
    resized.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        height_pixels (int):
            Height of the image.

            This field is a member of `oneof`_ ``_height_pixels``.
        width_pixels (int):
            Width of the image.

            This field is a member of `oneof`_ ``_width_pixels``.
        url (str):
            A URL that returns the image with this height
            and width.

            This field is a member of `oneof`_ ``_url``.
    """

    height_pixels: int = proto.Field(
        proto.INT64,
        number=4,
        optional=True,
    )
    width_pixels: int = proto.Field(
        proto.INT64,
        number=5,
        optional=True,
    )
    url: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )


class TextAsset(proto.Message):
    r"""A Text asset.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        text (str):
            Text content of the text asset.

            This field is a member of `oneof`_ ``_text``.
    """

    text: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class LeadFormAsset(proto.Message):
    r"""A Lead Form asset.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        business_name (str):
            Required. The name of the business being
            advertised.
        call_to_action_type (google.ads.googleads.v22.enums.types.LeadFormCallToActionTypeEnum.LeadFormCallToActionType):
            Required. Pre-defined display text that
            encourages user to expand the form.
        call_to_action_description (str):
            Required. Text giving a clear value
            proposition of what users expect once they
            expand the form.
        headline (str):
            Required. Headline of the expanded form to
            describe what the form is asking for or
            facilitating.
        description (str):
            Required. Detailed description of the
            expanded form to describe what the form is
            asking for or facilitating.
        privacy_policy_url (str):
            Required. Link to a page describing the
            policy on how the collected data is handled by
            the advertiser/business.
        post_submit_headline (str):
            Headline of text shown after form submission
            that describes how the advertiser will follow up
            with the user.

            This field is a member of `oneof`_ ``_post_submit_headline``.
        post_submit_description (str):
            Detailed description shown after form
            submission that describes how the advertiser
            will follow up with the user.

            This field is a member of `oneof`_ ``_post_submit_description``.
        fields (MutableSequence[google.ads.googleads.v22.common.types.LeadFormField]):
            Ordered list of input fields. This field can
            be updated by reordering questions, but not by
            adding or removing questions.
        custom_question_fields (MutableSequence[google.ads.googleads.v22.common.types.LeadFormCustomQuestionField]):
            Ordered list of custom question fields. This
            field is subject to a limit of 5 qualifying
            questions per form.
        delivery_methods (MutableSequence[google.ads.googleads.v22.common.types.LeadFormDeliveryMethod]):
            Configured methods for collected lead data to
            be delivered to advertiser. Only one method
            typed as WebhookDelivery can be configured.
        post_submit_call_to_action_type (google.ads.googleads.v22.enums.types.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType):
            Pre-defined display text that encourages user
            action after the form is submitted.
        background_image_asset (str):
            Asset resource name of the background image.
            The image dimensions must be exactly 1200x628.

            This field is a member of `oneof`_ ``_background_image_asset``.
        desired_intent (google.ads.googleads.v22.enums.types.LeadFormDesiredIntentEnum.LeadFormDesiredIntent):
            Chosen intent for the lead form, for example,
            more volume or more qualified.
        custom_disclosure (str):
            Custom disclosure shown along with Google
            disclaimer on the lead form. Accessible to
            allowed customers only.

            This field is a member of `oneof`_ ``_custom_disclosure``.
    """

    business_name: str = proto.Field(
        proto.STRING,
        number=10,
    )
    call_to_action_type: (
        lead_form_call_to_action_type.LeadFormCallToActionTypeEnum.LeadFormCallToActionType
    ) = proto.Field(
        proto.ENUM,
        number=17,
        enum=lead_form_call_to_action_type.LeadFormCallToActionTypeEnum.LeadFormCallToActionType,
    )
    call_to_action_description: str = proto.Field(
        proto.STRING,
        number=18,
    )
    headline: str = proto.Field(
        proto.STRING,
        number=12,
    )
    description: str = proto.Field(
        proto.STRING,
        number=13,
    )
    privacy_policy_url: str = proto.Field(
        proto.STRING,
        number=14,
    )
    post_submit_headline: str = proto.Field(
        proto.STRING,
        number=15,
        optional=True,
    )
    post_submit_description: str = proto.Field(
        proto.STRING,
        number=16,
        optional=True,
    )
    fields: MutableSequence["LeadFormField"] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message="LeadFormField",
    )
    custom_question_fields: MutableSequence["LeadFormCustomQuestionField"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=23,
            message="LeadFormCustomQuestionField",
        )
    )
    delivery_methods: MutableSequence["LeadFormDeliveryMethod"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=9,
            message="LeadFormDeliveryMethod",
        )
    )
    post_submit_call_to_action_type: (
        lead_form_post_submit_call_to_action_type.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType
    ) = proto.Field(
        proto.ENUM,
        number=19,
        enum=lead_form_post_submit_call_to_action_type.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType,
    )
    background_image_asset: str = proto.Field(
        proto.STRING,
        number=20,
        optional=True,
    )
    desired_intent: (
        lead_form_desired_intent.LeadFormDesiredIntentEnum.LeadFormDesiredIntent
    ) = proto.Field(
        proto.ENUM,
        number=21,
        enum=lead_form_desired_intent.LeadFormDesiredIntentEnum.LeadFormDesiredIntent,
    )
    custom_disclosure: str = proto.Field(
        proto.STRING,
        number=22,
        optional=True,
    )


class LeadFormField(proto.Message):
    r"""One input field instance within a form.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        input_type (google.ads.googleads.v22.enums.types.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType):
            Describes the input type, which may be a
            predefined type such as "full name" or a
            pre-vetted question like "What kind of vehicle
            do you have?".
        single_choice_answers (google.ads.googleads.v22.common.types.LeadFormSingleChoiceAnswers):
            Answer configuration for a single choice
            question. Can be set only for pre-vetted
            question fields. Minimum of 2 answers required
            and maximum of 12 allowed.

            This field is a member of `oneof`_ ``answers``.
        has_location_answer (bool):
            Answer configuration for location question. If true,
            campaign/account level location data (state, city, business
            name etc) will be rendered on the Lead Form. Starting V13.1,
            has_location_answer can only be set for "What is your
            preferred dealership?" question, for advertisers with
            Location Assets setup at campaign/account level.

            This field is a member of `oneof`_ ``answers``.
    """

    input_type: (
        lead_form_field_user_input_type.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=lead_form_field_user_input_type.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType,
    )
    single_choice_answers: "LeadFormSingleChoiceAnswers" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="answers",
        message="LeadFormSingleChoiceAnswers",
    )
    has_location_answer: bool = proto.Field(
        proto.BOOL,
        number=3,
        oneof="answers",
    )


class LeadFormCustomQuestionField(proto.Message):
    r"""One custom question input field instance within a form.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        custom_question_text (str):
            The exact custom question field text (for
            example, "What kind of vehicle do you have?").
        single_choice_answers (google.ads.googleads.v22.common.types.LeadFormSingleChoiceAnswers):
            Answer configuration for a single choice
            question. Minimum of 2 answers and maximum of 12
            allowed.

            This field is a member of `oneof`_ ``answers``.
        has_location_answer (bool):
            Answer configuration for location question. If true,
            campaign/account level location data (state, city, business
            name etc) will be rendered on the Lead Form. Starting V13.1,
            has_location_answer can only be set for "What is your
            preferred dealership?" question, for advertisers with
            Location Assets setup at campaign/account level.

            This field is a member of `oneof`_ ``answers``.
    """

    custom_question_text: str = proto.Field(
        proto.STRING,
        number=1,
    )
    single_choice_answers: "LeadFormSingleChoiceAnswers" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="answers",
        message="LeadFormSingleChoiceAnswers",
    )
    has_location_answer: bool = proto.Field(
        proto.BOOL,
        number=3,
        oneof="answers",
    )


class LeadFormSingleChoiceAnswers(proto.Message):
    r"""Defines possible answers for a single choice question,
    usually presented as a single-choice drop-down list.

    Attributes:
        answers (MutableSequence[str]):
            List of choices for a single question field.
            The order of entries defines UI order. Minimum
            of 2 answers required and maximum of 12 allowed.
    """

    answers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )


class LeadFormDeliveryMethod(proto.Message):
    r"""A configuration of how leads are delivered to the advertiser.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        webhook (google.ads.googleads.v22.common.types.WebhookDelivery):
            Webhook method of delivery.

            This field is a member of `oneof`_ ``delivery_details``.
    """

    webhook: "WebhookDelivery" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="delivery_details",
        message="WebhookDelivery",
    )


class WebhookDelivery(proto.Message):
    r"""Google notifies the advertiser of leads by making HTTP calls
    to an endpoint they specify. The requests contain JSON matching
    a schema that Google publishes as part of form ads
    documentation.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        advertiser_webhook_url (str):
            Webhook url specified by advertiser to send
            the lead.

            This field is a member of `oneof`_ ``_advertiser_webhook_url``.
        google_secret (str):
            Anti-spoofing secret set by the advertiser as
            part of the webhook payload.

            This field is a member of `oneof`_ ``_google_secret``.
        payload_schema_version (int):
            The schema version that this delivery
            instance will use.

            This field is a member of `oneof`_ ``_payload_schema_version``.
    """

    advertiser_webhook_url: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    google_secret: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    payload_schema_version: int = proto.Field(
        proto.INT64,
        number=6,
        optional=True,
    )


class BookOnGoogleAsset(proto.Message):
    r"""A Book on Google asset. Used to redirect user to book through
    Google. Book on Google will change the redirect url to book
    directly through Google.

    """


class PromotionAsset(proto.Message):
    r"""A Promotion asset.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        promotion_target (str):
            Required. A freeform description of what the
            promotion is targeting.
        discount_modifier (google.ads.googleads.v22.enums.types.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier):
            A modifier for qualification of the discount.
        redemption_start_date (str):
            Start date of when the promotion is eligible
            to be redeemed, in yyyy-MM-dd format.
        redemption_end_date (str):
            Last date of when the promotion is eligible
            to be redeemed, in yyyy-MM-dd format.
        occasion (google.ads.googleads.v22.enums.types.PromotionExtensionOccasionEnum.PromotionExtensionOccasion):
            The occasion the promotion was intended for.
            If an occasion is set, the redemption window
            will need to fall within the date range
            associated with the occasion.
        language_code (str):
            The language of the promotion.
            Represented as BCP 47 language tag.
        start_date (str):
            Start date of when this asset is effective
            and can begin serving, in yyyy-MM-dd format.
        end_date (str):
            Last date of when this asset is effective and
            still serving, in yyyy-MM-dd format.
        ad_schedule_targets (MutableSequence[google.ads.googleads.v22.common.types.AdScheduleInfo]):
            List of non-overlapping schedules specifying
            all time intervals for which the asset may
            serve. There can be a maximum of 6 schedules per
            day, 42 in total.
        terms_and_conditions_text (str):
            Terms and conditions of the promotion.
        terms_and_conditions_uri (str):
            URI to the terms and conditions of the
            promotion.
        percent_off (int):
            Percentage off discount in the promotion. 1,000,000 = 100%.
            Either this or money_amount_off is required.

            This field is a member of `oneof`_ ``discount_type``.
        money_amount_off (google.ads.googleads.v22.common.types.Money):
            Money amount off for discount in the promotion. Either this
            or percent_off is required.

            This field is a member of `oneof`_ ``discount_type``.
        promotion_code (str):
            A code the user should use in order to be
            eligible for the promotion.

            This field is a member of `oneof`_ ``promotion_trigger``.
        orders_over_amount (google.ads.googleads.v22.common.types.Money):
            The amount the total order needs to be for
            the user to be eligible for the promotion.

            This field is a member of `oneof`_ ``promotion_trigger``.
        promotion_barcode_info (google.ads.googleads.v22.common.types.PromotionBarcodeInfo):
            Barcode info used to generate promotion
            barcode for user to be eligible for the
            promotion.

            This field is a member of `oneof`_ ``promotion_trigger``.
        promotion_qr_code_info (google.ads.googleads.v22.common.types.PromotionQrCodeInfo):
            QR code info used to generate promotion QR
            code for user to be eligible for the promotion.

            This field is a member of `oneof`_ ``promotion_trigger``.
    """

    promotion_target: str = proto.Field(
        proto.STRING,
        number=1,
    )
    discount_modifier: (
        promotion_extension_discount_modifier.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=promotion_extension_discount_modifier.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier,
    )
    redemption_start_date: str = proto.Field(
        proto.STRING,
        number=7,
    )
    redemption_end_date: str = proto.Field(
        proto.STRING,
        number=8,
    )
    occasion: (
        promotion_extension_occasion.PromotionExtensionOccasionEnum.PromotionExtensionOccasion
    ) = proto.Field(
        proto.ENUM,
        number=9,
        enum=promotion_extension_occasion.PromotionExtensionOccasionEnum.PromotionExtensionOccasion,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=10,
    )
    start_date: str = proto.Field(
        proto.STRING,
        number=11,
    )
    end_date: str = proto.Field(
        proto.STRING,
        number=12,
    )
    ad_schedule_targets: MutableSequence[criteria.AdScheduleInfo] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=13,
            message=criteria.AdScheduleInfo,
        )
    )
    terms_and_conditions_text: str = proto.Field(
        proto.STRING,
        number=14,
    )
    terms_and_conditions_uri: str = proto.Field(
        proto.STRING,
        number=15,
    )
    percent_off: int = proto.Field(
        proto.INT64,
        number=3,
        oneof="discount_type",
    )
    money_amount_off: feed_common.Money = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="discount_type",
        message=feed_common.Money,
    )
    promotion_code: str = proto.Field(
        proto.STRING,
        number=5,
        oneof="promotion_trigger",
    )
    orders_over_amount: feed_common.Money = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="promotion_trigger",
        message=feed_common.Money,
    )
    promotion_barcode_info: "PromotionBarcodeInfo" = proto.Field(
        proto.MESSAGE,
        number=16,
        oneof="promotion_trigger",
        message="PromotionBarcodeInfo",
    )
    promotion_qr_code_info: "PromotionQrCodeInfo" = proto.Field(
        proto.MESSAGE,
        number=17,
        oneof="promotion_trigger",
        message="PromotionQrCodeInfo",
    )


class PromotionBarcodeInfo(proto.Message):
    r"""Barcode info to generate promotion barcode.

    Attributes:
        type_ (google.ads.googleads.v22.enums.types.PromotionBarcodeTypeEnum.PromotionBarcodeType):
            Barcode type used to generate barcode with
            the correct format.
        barcode_content (str):
            Promotion message to be encoded in the
            barcode.
    """

    type_: (
        promotion_barcode_type.PromotionBarcodeTypeEnum.PromotionBarcodeType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=promotion_barcode_type.PromotionBarcodeTypeEnum.PromotionBarcodeType,
    )
    barcode_content: str = proto.Field(
        proto.STRING,
        number=2,
    )


class PromotionQrCodeInfo(proto.Message):
    r"""QR code info to generate promotion QR code.

    Attributes:
        qr_code_content (str):
            Promotion message to be encoded in the QR
            code.
    """

    qr_code_content: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CalloutAsset(proto.Message):
    r"""A Callout asset.

    Attributes:
        callout_text (str):
            Required. The callout text.
            The length of this string should be between 1
            and 25, inclusive.
        start_date (str):
            Start date of when this asset is effective
            and can begin serving, in yyyy-MM-dd format.
        end_date (str):
            Last date of when this asset is effective and
            still serving, in yyyy-MM-dd format.
        ad_schedule_targets (MutableSequence[google.ads.googleads.v22.common.types.AdScheduleInfo]):
            List of non-overlapping schedules specifying
            all time intervals for which the asset may
            serve. There can be a maximum of 6 schedules per
            day, 42 in total.
    """

    callout_text: str = proto.Field(
        proto.STRING,
        number=1,
    )
    start_date: str = proto.Field(
        proto.STRING,
        number=2,
    )
    end_date: str = proto.Field(
        proto.STRING,
        number=3,
    )
    ad_schedule_targets: MutableSequence[criteria.AdScheduleInfo] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=criteria.AdScheduleInfo,
        )
    )


class StructuredSnippetAsset(proto.Message):
    r"""A Structured Snippet asset.

    Attributes:
        header (str):
            Required. The header of the snippet.
            This string should be one of the predefined
            values at
            https://developers.google.com/google-ads/api/reference/data/structured-snippet-headers
        values (MutableSequence[str]):
            Required. The values in the snippet.
            The size of this collection should be between 3
            and 10, inclusive. The length of each value
            should be between 1 and 25 characters,
            inclusive.
    """

    header: str = proto.Field(
        proto.STRING,
        number=1,
    )
    values: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class SitelinkAsset(proto.Message):
    r"""A Sitelink asset.

    Attributes:
        link_text (str):
            Required. URL display text for the sitelink.
            The length of this string should be between 1
            and 25, inclusive.
        description1 (str):
            First line of the description for the
            sitelink. If set, the length should be between 1
            and 35, inclusive, and description2 must also be
            set.
        description2 (str):
            Second line of the description for the
            sitelink. If set, the length should be between 1
            and 35, inclusive, and description1 must also be
            set.
        start_date (str):
            Start date of when this asset is effective
            and can begin serving, in yyyy-MM-dd format.
        end_date (str):
            Last date of when this asset is effective and
            still serving, in yyyy-MM-dd format.
        ad_schedule_targets (MutableSequence[google.ads.googleads.v22.common.types.AdScheduleInfo]):
            List of non-overlapping schedules specifying
            all time intervals for which the asset may
            serve. There can be a maximum of 6 schedules per
            day, 42 in total.
    """

    link_text: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description1: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description2: str = proto.Field(
        proto.STRING,
        number=3,
    )
    start_date: str = proto.Field(
        proto.STRING,
        number=4,
    )
    end_date: str = proto.Field(
        proto.STRING,
        number=5,
    )
    ad_schedule_targets: MutableSequence[criteria.AdScheduleInfo] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=6,
            message=criteria.AdScheduleInfo,
        )
    )


class PageFeedAsset(proto.Message):
    r"""A Page Feed asset.

    Attributes:
        page_url (str):
            Required. The webpage that advertisers want
            to target.
        labels (MutableSequence[str]):
            Labels used to group the page urls.
    """

    page_url: str = proto.Field(
        proto.STRING,
        number=1,
    )
    labels: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class DynamicEducationAsset(proto.Message):
    r"""A Dynamic Education asset.

    Attributes:
        program_id (str):
            Required. Program ID which can be any
            sequence of letters and digits, and must be
            unique and match the values of remarketing tag.
            Required.
        location_id (str):
            Location ID which can be any sequence of
            letters and digits and must be unique.
        program_name (str):
            Required. Program name, for example, Nursing.
            Required.
        subject (str):
            Subject of study, for example, Health.
        program_description (str):
            Program description, for example, Nursing
            Certification.
        school_name (str):
            School name, for example, Mountain View
            School of Nursing.
        address (str):
            School address which can be specified in one
            of the following formats. (1) City, state, code,
            country, for example, Mountain View, CA, USA.
            (2) Full address, for example, 123 Boulevard St,
            Mountain View, CA 94043. (3) Latitude-longitude
            in the DDD format, for example, 41.40338,
            2.17403
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, Nursing
            certification, Health, Mountain View.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        similar_program_ids (MutableSequence[str]):
            Similar program IDs.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
        thumbnail_image_url (str):
            Thumbnail image url, for example,
            http://www.example.com/thumbnail.png. The
            thumbnail image will not be uploaded as image
            asset.
        image_url (str):
            Image url, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
    """

    program_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    program_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    subject: str = proto.Field(
        proto.STRING,
        number=4,
    )
    program_description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    school_name: str = proto.Field(
        proto.STRING,
        number=6,
    )
    address: str = proto.Field(
        proto.STRING,
        number=7,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=9,
    )
    similar_program_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=11,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=12,
    )
    thumbnail_image_url: str = proto.Field(
        proto.STRING,
        number=13,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=14,
    )


class MobileAppAsset(proto.Message):
    r"""An asset representing a mobile app.

    Attributes:
        app_id (str):
            Required. A string that uniquely identifies a
            mobile application. It should just contain the
            platform native id, like "com.android.ebay" for
            Android or "12345689" for iOS.
        app_store (google.ads.googleads.v22.enums.types.MobileAppVendorEnum.MobileAppVendor):
            Required. The application store that
            distributes this specific app.
        link_text (str):
            Required. The visible text displayed when the
            link is rendered in an ad. The length of this
            string should be between 1 and 25, inclusive.
        start_date (str):
            Start date of when this asset is effective
            and can begin serving, in yyyy-MM-dd format.
        end_date (str):
            Last date of when this asset is effective and
            still serving, in yyyy-MM-dd format.
    """

    app_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    app_store: mobile_app_vendor.MobileAppVendorEnum.MobileAppVendor = (
        proto.Field(
            proto.ENUM,
            number=2,
            enum=mobile_app_vendor.MobileAppVendorEnum.MobileAppVendor,
        )
    )
    link_text: str = proto.Field(
        proto.STRING,
        number=3,
    )
    start_date: str = proto.Field(
        proto.STRING,
        number=4,
    )
    end_date: str = proto.Field(
        proto.STRING,
        number=5,
    )


class HotelCalloutAsset(proto.Message):
    r"""An asset representing a hotel callout.

    Attributes:
        text (str):
            Required. The text of the hotel callout
            asset. The length of this string should be
            between 1 and 25, inclusive.
        language_code (str):
            Required. The language of the hotel callout.
            Represented as BCP 47 language tag.
    """

    text: str = proto.Field(
        proto.STRING,
        number=1,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CallAsset(proto.Message):
    r"""A Call asset.

    Attributes:
        country_code (str):
            Required. Two-letter country code of the
            phone number. Examples: 'US', 'us'.
        phone_number (str):
            Required. The advertiser's raw phone number.
            Examples: '1234567890', '(123)456-7890'
        call_conversion_reporting_state (google.ads.googleads.v22.enums.types.CallConversionReportingStateEnum.CallConversionReportingState):
            Indicates whether this CallAsset should use
            its own call conversion setting, follow the
            account level setting, or disable call
            conversion.
        call_conversion_action (str):
            The conversion action to attribute a call conversion to. If
            not set, the default conversion action is used. This field
            only has effect if call_conversion_reporting_state is set to
            USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION.
        ad_schedule_targets (MutableSequence[google.ads.googleads.v22.common.types.AdScheduleInfo]):
            List of non-overlapping schedules specifying
            all time intervals for which the asset may
            serve. There can be a maximum of 6 schedules per
            day, 42 in total.
    """

    country_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    phone_number: str = proto.Field(
        proto.STRING,
        number=2,
    )
    call_conversion_reporting_state: (
        gage_call_conversion_reporting_state.CallConversionReportingStateEnum.CallConversionReportingState
    ) = proto.Field(
        proto.ENUM,
        number=3,
        enum=gage_call_conversion_reporting_state.CallConversionReportingStateEnum.CallConversionReportingState,
    )
    call_conversion_action: str = proto.Field(
        proto.STRING,
        number=4,
    )
    ad_schedule_targets: MutableSequence[criteria.AdScheduleInfo] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=5,
            message=criteria.AdScheduleInfo,
        )
    )


class PriceAsset(proto.Message):
    r"""An asset representing a list of price offers.

    Attributes:
        type_ (google.ads.googleads.v22.enums.types.PriceExtensionTypeEnum.PriceExtensionType):
            Required. The type of the price asset.
        price_qualifier (google.ads.googleads.v22.enums.types.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier):
            The price qualifier of the price asset.
        language_code (str):
            Required. The language of the price asset.
            Represented as BCP 47 language tag.
        price_offerings (MutableSequence[google.ads.googleads.v22.common.types.PriceOffering]):
            The price offerings of the price asset.
            The size of this collection should be between 3
            and 8, inclusive.
    """

    type_: price_extension_type.PriceExtensionTypeEnum.PriceExtensionType = (
        proto.Field(
            proto.ENUM,
            number=1,
            enum=price_extension_type.PriceExtensionTypeEnum.PriceExtensionType,
        )
    )
    price_qualifier: (
        price_extension_price_qualifier.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=price_extension_price_qualifier.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=3,
    )
    price_offerings: MutableSequence["PriceOffering"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="PriceOffering",
    )


class PriceOffering(proto.Message):
    r"""A single price offering within a PriceAsset.

    Attributes:
        header (str):
            Required. The header of the price offering.
            The length of this string should be between 1
            and 25, inclusive.
        description (str):
            Required. The description of the price
            offering. The length of this string should be
            between 1 and 25, inclusive.
        price (google.ads.googleads.v22.common.types.Money):
            Required. The price value of the price
            offering.
        unit (google.ads.googleads.v22.enums.types.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit):
            The price unit of the price offering.
        final_url (str):
            Required. The final URL after all cross
            domain redirects.
        final_mobile_url (str):
            The final mobile URL after all cross domain
            redirects.
    """

    header: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    price: feed_common.Money = proto.Field(
        proto.MESSAGE,
        number=3,
        message=feed_common.Money,
    )
    unit: (
        price_extension_price_unit.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit
    ) = proto.Field(
        proto.ENUM,
        number=4,
        enum=price_extension_price_unit.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit,
    )
    final_url: str = proto.Field(
        proto.STRING,
        number=5,
    )
    final_mobile_url: str = proto.Field(
        proto.STRING,
        number=6,
    )


class CallToActionAsset(proto.Message):
    r"""A call to action asset.

    Attributes:
        call_to_action (google.ads.googleads.v22.enums.types.CallToActionTypeEnum.CallToActionType):
            Call to action.
    """

    call_to_action: (
        gage_call_to_action_type.CallToActionTypeEnum.CallToActionType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=gage_call_to_action_type.CallToActionTypeEnum.CallToActionType,
    )


class DynamicRealEstateAsset(proto.Message):
    r"""A dynamic real estate asset.

    Attributes:
        listing_id (str):
            Required. Listing ID which can be any
            sequence of letters and digits, and must be
            unique and match the values of remarketing tag.
            Required.
        listing_name (str):
            Required. Listing name, for example,
            Boulevard Bungalow. Required.
        city_name (str):
            City name, for example, Mountain View,
            California.
        description (str):
            Description, for example, 3 beds, 2 baths,
            1568 sq. ft.
        address (str):
            Address which can be specified in one of the
            following formats. (1) City, state, code,
            country, for example, Mountain View, CA, USA.
            (2) Full address, for example, 123 Boulevard St,
            Mountain View, CA 94043. (3) Latitude-longitude
            in the DDD format, for example, 41.40338,
            2.17403
        price (str):
            Price which can be number followed by the
            alphabetic currency code, ISO 4217 standard. Use
            '.' as the decimal mark, for example, 200,000.00
            USD.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        property_type (str):
            Property type, for example, House.
        listing_type (str):
            Listing type, for example, For sale.
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, For sale;
            Houses for sale.
        formatted_price (str):
            Formatted price which can be any characters.
            If set, this attribute will be used instead of
            'price', for example, Starting at $200,000.00.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
        similar_listing_ids (MutableSequence[str]):
            Similar listing IDs.
    """

    listing_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    listing_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    city_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
    )
    address: str = proto.Field(
        proto.STRING,
        number=5,
    )
    price: str = proto.Field(
        proto.STRING,
        number=6,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=7,
    )
    property_type: str = proto.Field(
        proto.STRING,
        number=8,
    )
    listing_type: str = proto.Field(
        proto.STRING,
        number=9,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )
    formatted_price: str = proto.Field(
        proto.STRING,
        number=11,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=12,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=13,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=14,
    )
    similar_listing_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=15,
    )


class DynamicCustomAsset(proto.Message):
    r"""A dynamic custom asset.

    Attributes:
        id (str):
            Required. ID which can be any sequence of
            letters and digits, and must be unique and match
            the values of remarketing tag, for example,
            sedan. Required.
        id2 (str):
            ID2 which can be any sequence of letters and
            digits, for example, red. ID sequence (ID + ID2)
            must be unique.
        item_title (str):
            Required. Item title, for example, Mid-size
            sedan. Required.
        item_subtitle (str):
            Item subtitle, for example, At your Mountain
            View dealership.
        item_description (str):
            Item description, for example, Best selling
            mid-size car.
        item_address (str):
            Item address which can be specified in one of
            the following formats. (1) City, state, code,
            country, for example, Mountain View, CA, USA.
            (2) Full address, for example, 123 Boulevard St,
            Mountain View, CA 94043. (3) Latitude-longitude
            in the DDD format, for example, 41.40338,
            2.17403
        item_category (str):
            Item category, for example, Sedans.
        price (str):
            Price which can be number followed by the
            alphabetic currency code, ISO 4217 standard. Use
            '.' as the decimal mark, for example, 20,000.00
            USD.
        sale_price (str):
            Sale price which can be number followed by
            the alphabetic currency code, ISO 4217 standard.
            Use '.' as the decimal mark, for example,
            15,000.00 USD. Must be less than the 'price'
            field.
        formatted_price (str):
            Formatted price which can be any characters.
            If set, this attribute will be used instead of
            'price', for example, Starting at $20,000.00.
        formatted_sale_price (str):
            Formatted sale price which can be any
            characters. If set, this attribute will be used
            instead of 'sale price', for example, On sale
            for $15,000.00.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, Sedans, 4
            door sedans.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
        similar_ids (MutableSequence[str]):
            Similar IDs.
    """

    id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id2: str = proto.Field(
        proto.STRING,
        number=2,
    )
    item_title: str = proto.Field(
        proto.STRING,
        number=3,
    )
    item_subtitle: str = proto.Field(
        proto.STRING,
        number=4,
    )
    item_description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    item_address: str = proto.Field(
        proto.STRING,
        number=6,
    )
    item_category: str = proto.Field(
        proto.STRING,
        number=7,
    )
    price: str = proto.Field(
        proto.STRING,
        number=8,
    )
    sale_price: str = proto.Field(
        proto.STRING,
        number=9,
    )
    formatted_price: str = proto.Field(
        proto.STRING,
        number=10,
    )
    formatted_sale_price: str = proto.Field(
        proto.STRING,
        number=11,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=12,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=13,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=14,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=16,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=17,
    )
    similar_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=15,
    )


class DynamicHotelsAndRentalsAsset(proto.Message):
    r"""A dynamic hotels and rentals asset.

    Attributes:
        property_id (str):
            Required. Property ID which can be any
            sequence of letters and digits, and must be
            unique and match the values of remarketing tag.
            Required.
        property_name (str):
            Required. Property name, for example,
            Mountain View Hotel. Required.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        destination_name (str):
            Destination name, for example, Downtown
            Mountain View.
        description (str):
            Description, for example, Close to SJC
            Airport.
        price (str):
            Price which can be number followed by the
            alphabetic currency code, ISO 4217 standard. Use
            '.' as the decimal mark, for example, 100.00
            USD.
        sale_price (str):
            ISO 4217 standard. Use '.' as the decimal
            mark, for example, 80.00 USD. Must be less than
            the 'price' field.
        star_rating (int):
            Star rating. Must be a number between 1 to 5,
            inclusive.
        category (str):
            Category, for example, Hotel suite.
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, Mountain
            View "Hotels", South Bay hotels.
        address (str):
            Address which can be specified in one of the
            following formats. (1) City, state, code,
            country, for example, Mountain View, CA, USA.
            (2) Full address, for example, 123 Boulevard St,
            Mountain View, CA 94043. (3) Latitude-longitude
            in the DDD format, for example, 41.40338,
            2.17403
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
        formatted_price (str):
            Formatted price which can be any characters.
            If set, this attribute will be used instead of
            'price', for example, Starting at $100.00.
        formatted_sale_price (str):
            Formatted sale price which can be any
            characters. If set, this attribute will be used
            instead of 'sale price', for example, On sale
            for $80.00.
        similar_property_ids (MutableSequence[str]):
            Similar property IDs.
    """

    property_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    property_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=3,
    )
    destination_name: str = proto.Field(
        proto.STRING,
        number=4,
    )
    description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    price: str = proto.Field(
        proto.STRING,
        number=6,
    )
    sale_price: str = proto.Field(
        proto.STRING,
        number=7,
    )
    star_rating: int = proto.Field(
        proto.INT64,
        number=8,
    )
    category: str = proto.Field(
        proto.STRING,
        number=9,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )
    address: str = proto.Field(
        proto.STRING,
        number=11,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=12,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=13,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=14,
    )
    formatted_price: str = proto.Field(
        proto.STRING,
        number=15,
    )
    formatted_sale_price: str = proto.Field(
        proto.STRING,
        number=16,
    )
    similar_property_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=17,
    )


class DynamicFlightsAsset(proto.Message):
    r"""A dynamic flights asset.

    Attributes:
        destination_id (str):
            Required. Destination ID which can be any
            sequence of letters and digits, and must be
            unique and match the values of remarketing tag.
            Required.
        origin_id (str):
            Origin ID which can be any sequence of
            letters and digits. The ID sequence (destination
            ID + origin ID) must be unique.
        flight_description (str):
            Required. Flight description, for example,
            Book your ticket. Required.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        destination_name (str):
            Destination name, for example, Paris.
        origin_name (str):
            Origin name, for example, London.
        flight_price (str):
            Flight price which can be number followed by
            the alphabetic currency code, ISO 4217 standard.
            Use '.' as the decimal mark, for example, 100.00
            USD.
        flight_sale_price (str):
            Flight sale price which can be number followed by the
            alphabetic currency code, ISO 4217 standard. Use '.' as the
            decimal mark, for example, 80.00 USD. Must be less than the
            'flight_price' field.
        formatted_price (str):
            Formatted price which can be any characters.
            If set, this attribute will be used instead of
            'price', for example, Starting at $100.00.
        formatted_sale_price (str):
            Formatted sale price which can be any
            characters. If set, this attribute will be used
            instead of 'sale price', for example, On sale
            for $80.00.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
        similar_destination_ids (MutableSequence[str]):
            Similar destination IDs, for example,
            PAR,LON.
        custom_mapping (str):
            A custom field which can be multiple key to values mapping
            separated by delimiters (",", "\|" and ":"), in the forms of
            "<KEY_1>: <VALUE_1>, <VALUE_2>, ... ,<VALUE_N> \| <KEY_2>:
            <VALUE_1>, ... ,<VALUE_N> \| ... \| <KEY_N>: <VALUE_1>, ...
            ,<VALUE_N>" for example, wifi: most \| aircraft: 320, 77W \|
            flights: 42 \| legroom: 32".
    """

    destination_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    origin_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    flight_description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=4,
    )
    destination_name: str = proto.Field(
        proto.STRING,
        number=5,
    )
    origin_name: str = proto.Field(
        proto.STRING,
        number=6,
    )
    flight_price: str = proto.Field(
        proto.STRING,
        number=7,
    )
    flight_sale_price: str = proto.Field(
        proto.STRING,
        number=8,
    )
    formatted_price: str = proto.Field(
        proto.STRING,
        number=9,
    )
    formatted_sale_price: str = proto.Field(
        proto.STRING,
        number=10,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=11,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=12,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=13,
    )
    similar_destination_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=14,
    )
    custom_mapping: str = proto.Field(
        proto.STRING,
        number=15,
    )


class DemandGenCarouselCardAsset(proto.Message):
    r"""A Demand Gen Carousel Card asset.

    Attributes:
        marketing_image_asset (str):
            Asset resource name of the associated 1.91:1
            marketing image. This and/or square marketing
            image asset is required.
        square_marketing_image_asset (str):
            Asset resource name of the associated square
            marketing image. This and/or a marketing image
            asset is required.
        portrait_marketing_image_asset (str):
            Asset resource name of the associated 4:5
            portrait marketing image.
        headline (str):
            Required. Headline of the carousel card.
        call_to_action_text (str):
            Call to action text.
    """

    marketing_image_asset: str = proto.Field(
        proto.STRING,
        number=1,
    )
    square_marketing_image_asset: str = proto.Field(
        proto.STRING,
        number=2,
    )
    portrait_marketing_image_asset: str = proto.Field(
        proto.STRING,
        number=3,
    )
    headline: str = proto.Field(
        proto.STRING,
        number=4,
    )
    call_to_action_text: str = proto.Field(
        proto.STRING,
        number=5,
    )


class DynamicTravelAsset(proto.Message):
    r"""A dynamic travel asset.

    Attributes:
        destination_id (str):
            Required. Destination ID which can be any
            sequence of letters and digits, and must be
            unique and match the values of remarketing tag.
            Required.
        origin_id (str):
            Origin ID which can be any sequence of
            letters and digits. The ID sequence (destination
            ID + origin ID) must be unique.
        title (str):
            Required. Title, for example, Book your train
            ticket. Required.
        destination_name (str):
            Destination name, for example, Paris.
        destination_address (str):
            Destination address which can be specified in
            one of the following formats. (1) City, state,
            code, country, for example, Mountain View, CA,
            USA. (2) Full address, for example, 123
            Boulevard St, Mountain View, CA 94043. (3)
            Latitude-longitude in the DDD format, for
            example, 41.40338, 2.17403.
        origin_name (str):
            Origin name, for example, London.
        price (str):
            Price which can be a number followed by the
            alphabetic currency code, ISO 4217 standard. Use
            '.' as the decimal mark, for example, 100.00
            USD.
        sale_price (str):
            Sale price which can be a number followed by
            the alphabetic currency code, ISO 4217 standard.
            Use '.' as the decimal mark, for example, 80.00
            USD. Must be less than the 'price' field.
        formatted_price (str):
            Formatted price which can be any characters.
            If set, this attribute will be used instead of
            'price', for example, Starting at $100.00.
        formatted_sale_price (str):
            Formatted sale price which can be any
            characters. If set, this attribute will be used
            instead of 'sale price', for example, On sale
            for $80.00.
        category (str):
            Category, for example, Express.
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, Paris
            trains.
        similar_destination_ids (MutableSequence[str]):
            Similar destination IDs, for example, NYC.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
    """

    destination_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    origin_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    title: str = proto.Field(
        proto.STRING,
        number=3,
    )
    destination_name: str = proto.Field(
        proto.STRING,
        number=4,
    )
    destination_address: str = proto.Field(
        proto.STRING,
        number=5,
    )
    origin_name: str = proto.Field(
        proto.STRING,
        number=6,
    )
    price: str = proto.Field(
        proto.STRING,
        number=7,
    )
    sale_price: str = proto.Field(
        proto.STRING,
        number=8,
    )
    formatted_price: str = proto.Field(
        proto.STRING,
        number=9,
    )
    formatted_sale_price: str = proto.Field(
        proto.STRING,
        number=10,
    )
    category: str = proto.Field(
        proto.STRING,
        number=11,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=12,
    )
    similar_destination_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=13,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=14,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=15,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=16,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=17,
    )


class DynamicLocalAsset(proto.Message):
    r"""A dynamic local asset.

    Attributes:
        deal_id (str):
            Required. Deal ID which can be any sequence
            of letters and digits, and must be unique and
            match the values of remarketing tag. Required.
        deal_name (str):
            Required. Deal name, for example, 50% off at
            Mountain View Grocers. Required.
        subtitle (str):
            Subtitle, for example, Groceries.
        description (str):
            Description, for example, Save on your weekly
            bill.
        price (str):
            Price which can be a number followed by the
            alphabetic currency code, ISO 4217 standard. Use
            '.' as the decimal mark, for example, 100.00
            USD.
        sale_price (str):
            Sale price which can be number followed by
            the alphabetic currency code, ISO 4217 standard.
            Use '.' as the decimal mark, for example, 80.00
            USD. Must be less than the 'price' field.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        address (str):
            Address which can be specified in one of the
            following formats. (1) City, state, code,
            country, for example, Mountain View, CA, USA.
            (2) Full address, for example, 123 Boulevard St,
            Mountain View, CA 94043. (3) Latitude-longitude
            in the DDD format, for example, 41.40338,
            2.17403.
        category (str):
            Category, for example, Food.
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, Save
            groceries coupons.
        formatted_price (str):
            Formatted price which can be any characters.
            If set, this attribute will be used instead of
            'price', for example, Starting at $100.00.
        formatted_sale_price (str):
            Formatted sale price which can be any
            characters. If set, this attribute will be used
            instead of 'sale price', for example, On sale
            for $80.00.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        similar_deal_ids (MutableSequence[str]):
            Similar deal IDs, for example, 1275.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
    """

    deal_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    deal_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    subtitle: str = proto.Field(
        proto.STRING,
        number=3,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
    )
    price: str = proto.Field(
        proto.STRING,
        number=5,
    )
    sale_price: str = proto.Field(
        proto.STRING,
        number=6,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=7,
    )
    address: str = proto.Field(
        proto.STRING,
        number=8,
    )
    category: str = proto.Field(
        proto.STRING,
        number=9,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )
    formatted_price: str = proto.Field(
        proto.STRING,
        number=11,
    )
    formatted_sale_price: str = proto.Field(
        proto.STRING,
        number=12,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=13,
    )
    similar_deal_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=14,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=15,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=16,
    )


class DynamicJobsAsset(proto.Message):
    r"""A dynamic jobs asset.

    Attributes:
        job_id (str):
            Required. Job ID which can be any sequence of
            letters and digits, and must be unique and match
            the values of remarketing tag. Required.
        location_id (str):
            Location ID which can be any sequence of
            letters and digits. The ID sequence (job ID +
            location ID) must be unique.
        job_title (str):
            Required. Job title, for example, Software
            engineer. Required.
        job_subtitle (str):
            Job subtitle, for example, Level II.
        description (str):
            Description, for example, Apply your
            technical skills.
        image_url (str):
            Image URL, for example,
            http://www.example.com/image.png. The image will
            not be uploaded as image asset.
        job_category (str):
            Job category, for example, Technical.
        contextual_keywords (MutableSequence[str]):
            Contextual keywords, for example, Software
            engineering job.
        address (str):
            Address which can be specified in one of the
            following formats. (1) City, state, code,
            country, for example, Mountain View, CA, USA.
            (2) Full address, for example, 123 Boulevard St,
            Mountain View, CA 94043. (3) Latitude-longitude
            in the DDD format, for example, 41.40338,
            2.17403.
        salary (str):
            Salary, for example, $100,000.
        android_app_link (str):
            Android deep link, for example,
            android-app://com.example.android/http/example.com/gizmos?1234.
        similar_job_ids (MutableSequence[str]):
            Similar job IDs, for example, 1275.
        ios_app_link (str):
            iOS deep link, for example,
            exampleApp://content/page.
        ios_app_store_id (int):
            iOS app store ID. This is used to check if the user has the
            app installed on their device before deep linking. If this
            field is set, then the ios_app_link field must also be
            present.
    """

    job_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    job_title: str = proto.Field(
        proto.STRING,
        number=3,
    )
    job_subtitle: str = proto.Field(
        proto.STRING,
        number=4,
    )
    description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    image_url: str = proto.Field(
        proto.STRING,
        number=6,
    )
    job_category: str = proto.Field(
        proto.STRING,
        number=7,
    )
    contextual_keywords: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )
    address: str = proto.Field(
        proto.STRING,
        number=9,
    )
    salary: str = proto.Field(
        proto.STRING,
        number=10,
    )
    android_app_link: str = proto.Field(
        proto.STRING,
        number=11,
    )
    similar_job_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=12,
    )
    ios_app_link: str = proto.Field(
        proto.STRING,
        number=13,
    )
    ios_app_store_id: int = proto.Field(
        proto.INT64,
        number=14,
    )


class LocationAsset(proto.Message):
    r"""A location asset.

    Attributes:
        place_id (str):
            Place IDs uniquely identify a place in the
            Google Places database and on Google Maps.
            This field is unique for a given customer ID and
            asset type. See
            https://developers.google.com/places/web-service/place-id
            to learn more about Place ID.
        business_profile_locations (MutableSequence[google.ads.googleads.v22.common.types.BusinessProfileLocation]):
            The list of business locations for the
            customer. This will only be returned if the
            Location Asset is syncing from the Business
            Profile account. It is possible to have multiple
            Business Profile listings under the same account
            that point to the same Place ID.
        location_ownership_type (google.ads.googleads.v22.enums.types.LocationOwnershipTypeEnum.LocationOwnershipType):
            The type of location ownership. If the type is
            BUSINESS_OWNER, it will be served as a location extension.
            If the type is AFFILIATE, it will be served as an affiliate
            location.
    """

    place_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    business_profile_locations: MutableSequence["BusinessProfileLocation"] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="BusinessProfileLocation",
        )
    )
    location_ownership_type: (
        gage_location_ownership_type.LocationOwnershipTypeEnum.LocationOwnershipType
    ) = proto.Field(
        proto.ENUM,
        number=3,
        enum=gage_location_ownership_type.LocationOwnershipTypeEnum.LocationOwnershipType,
    )


class BusinessProfileLocation(proto.Message):
    r"""Business Profile location data synced from the linked
    Business Profile account.

    Attributes:
        labels (MutableSequence[str]):
            Advertiser specified label for the location
            on the Business Profile account. This is synced
            from the Business Profile account.
        store_code (str):
            Business Profile store code of this location.
            This is synced from the Business Profile
            account.
        listing_id (int):
            Listing ID of this Business Profile location.
            This is synced from the linked Business Profile
            account.
    """

    labels: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    store_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    listing_id: int = proto.Field(
        proto.INT64,
        number=3,
    )


class HotelPropertyAsset(proto.Message):
    r"""A hotel property asset.

    Attributes:
        place_id (str):
            Place IDs uniquely identify a place in the
            Google Places database and on Google Maps. See
            https://developers.google.com/places/web-service/place-id
            to learn more.
        hotel_address (str):
            Address of the hotel. Read-only.
        hotel_name (str):
            Name of the hotel. Read-only.
    """

    place_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    hotel_address: str = proto.Field(
        proto.STRING,
        number=2,
    )
    hotel_name: str = proto.Field(
        proto.STRING,
        number=3,
    )


class BusinessMessageAsset(proto.Message):
    r"""A business message asset.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        message_provider (google.ads.googleads.v22.enums.types.BusinessMessageProviderEnum.BusinessMessageProvider):
            Required. Message provider of the business
            message asset.
        starter_message (str):
            Required. A welcome message to prompt the
            user to initiate a conversation.
        call_to_action (google.ads.googleads.v22.common.types.BusinessMessageCallToActionInfo):
            A call to action for the business message
            asset.

            This field is a member of `oneof`_ ``_call_to_action``.
        whatsapp_info (google.ads.googleads.v22.common.types.WhatsappBusinessMessageInfo):
            Whatsapp.

            This field is a member of `oneof`_ ``message_provider_data``.
    """

    message_provider: (
        business_message_provider.BusinessMessageProviderEnum.BusinessMessageProvider
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=business_message_provider.BusinessMessageProviderEnum.BusinessMessageProvider,
    )
    starter_message: str = proto.Field(
        proto.STRING,
        number=2,
    )
    call_to_action: "BusinessMessageCallToActionInfo" = proto.Field(
        proto.MESSAGE,
        number=3,
        optional=True,
        message="BusinessMessageCallToActionInfo",
    )
    whatsapp_info: "WhatsappBusinessMessageInfo" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="message_provider_data",
        message="WhatsappBusinessMessageInfo",
    )


class WhatsappBusinessMessageInfo(proto.Message):
    r"""Whatsapp information to use for messaging.

    Attributes:
        country_code (str):
            Required. Two-letter country code of the
            phone number. Examples: 'US', 'us'.
        phone_number (str):
            Required. Whatsapp phone number of the
            business. Examples: '1234567890',
            '(123)456-7890'.
    """

    country_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    phone_number: str = proto.Field(
        proto.STRING,
        number=2,
    )


class BusinessMessageCallToActionInfo(proto.Message):
    r"""Display information that encourages the user to take action.

    Attributes:
        call_to_action_selection (google.ads.googleads.v22.enums.types.BusinessMessageCallToActionTypeEnum.BusinessMessageCallToActionType):
            Required. Pre-defined call to action text.
        call_to_action_description (str):
            Required. Text providing a clear value
            proposition of what users expect once they take
            the action. Examples: 'Message us for a quote',
            'Ask our expert team'.
    """

    call_to_action_selection: (
        business_message_call_to_action_type.BusinessMessageCallToActionTypeEnum.BusinessMessageCallToActionType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=business_message_call_to_action_type.BusinessMessageCallToActionTypeEnum.BusinessMessageCallToActionType,
    )
    call_to_action_description: str = proto.Field(
        proto.STRING,
        number=2,
    )


class AppDeepLinkAsset(proto.Message):
    r"""An app deep link asset

    Attributes:
        app_deep_link_uri (str):
            The uri for the app deep link, The uri can be
            either a custom scheme uri (e.g.
            mystore://shoes) or universal uri (e.g.
            http://www.mystore.com/shoes).
    """

    app_deep_link_uri: str = proto.Field(
        proto.STRING,
        number=1,
    )


class YouTubeVideoListAsset(proto.Message):
    r"""A YouTube video list asset.

    Attributes:
        youtube_videos (MutableSequence[google.ads.googleads.v22.common.types.AdVideoAsset]):
            List of videos. Each is a reference to a
            YouTube video asset. Minimum of 2 videos
            required and maximum of 5 allowed.
    """

    youtube_videos: MutableSequence[ad_asset.AdVideoAsset] = (
        proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=ad_asset.AdVideoAsset,
        )
    )


__all__ = tuple(sorted(__protobuf__.manifest))
